# Copyright (c) 2017, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject, AWSProperty
from .validators import boolean, positive_integer

VALID_RECOVERYOPTION_NAME = ("admin_only", "verified_email", "verified_phone_number")


def validate_recoveryoption_name(recoveryoption_name):
    """Validate Name for RecoveryOption"""

    if recoveryoption_name not in VALID_RECOVERYOPTION_NAME:
        raise ValueError(
            "RecoveryOption Name must be one of: %s"
            % ", ".join(VALID_RECOVERYOPTION_NAME)
        )
    return recoveryoption_name


class CognitoIdentityProvider(AWSProperty):
    props = {
        "ClientId": (str, False),
        "ProviderName": (str, False),
        "ServerSideTokenCheck": (bool, False),
    }


class CognitoStreams(AWSProperty):
    props = {
        "RoleArn": (str, False),
        "StreamingStatus": (str, False),
        "StreamName": (str, False),
    }


class PushSync(AWSProperty):
    props = {
        "ApplicationArns": ([str], False),
        "RoleArn": (str, False),
    }


class IdentityPool(AWSObject):
    resource_type = "AWS::Cognito::IdentityPool"

    props = {
        "AllowUnauthenticatedIdentities": (bool, True),
        "CognitoEvents": (dict, False),
        "CognitoIdentityProviders": ([CognitoIdentityProvider], False),
        "CognitoStreams": (CognitoStreams, False),
        "DeveloperProviderName": (str, False),
        "IdentityPoolName": (str, False),
        "OpenIdConnectProviderARNs": ([str], False),
        "PushSync": (PushSync, False),
        "SamlProviderARNs": ([str], False),
        "SupportedLoginProviders": (dict, False),
    }


class MappingRule(AWSProperty):
    props = {
        "Claim": (str, True),
        "MatchType": (str, True),
        "RoleARN": (str, True),
        "Value": (str, True),
    }


class RulesConfiguration(AWSProperty):
    props = {
        "Rules": ([MappingRule], True),
    }


class RoleMapping(AWSProperty):
    props = {
        "AmbiguousRoleResolution": (str, False),
        "RulesConfiguration": (RulesConfiguration, False),
        "Type": (str, True),
    }


class IdentityPoolRoleAttachment(AWSObject):
    resource_type = "AWS::Cognito::IdentityPoolRoleAttachment"

    props = {
        "IdentityPoolId": (str, True),
        "RoleMappings": (dict, False),
        "Roles": (dict, False),
    }


class InviteMessageTemplate(AWSProperty):
    props = {
        "EmailMessage": (str, False),
        "EmailSubject": (str, False),
        "SMSMessage": (str, False),
    }


class AdminCreateUserConfig(AWSProperty):
    props = {
        "AllowAdminCreateUserOnly": (boolean, False),
        "InviteMessageTemplate": (InviteMessageTemplate, False),
        "UnusedAccountValidityDays": (positive_integer, False),
    }


class DeviceConfiguration(AWSProperty):
    props = {
        "ChallengeRequiredOnNewDevice": (boolean, False),
        "DeviceOnlyRememberedOnUserPrompt": (boolean, False),
    }


class EmailConfiguration(AWSProperty):
    props = {
        "ConfigurationSet": (str, False),
        "EmailSendingAccount": (str, False),
        "From": (str, False),
        "ReplyToEmailAddress": (str, False),
        "SourceArn": (str, False),
    }


class LambdaConfig(AWSProperty):
    props = {
        "CreateAuthChallenge": (str, False),
        "CustomMessage": (str, False),
        "DefineAuthChallenge": (str, False),
        "PostAuthentication": (str, False),
        "PostConfirmation": (str, False),
        "PreAuthentication": (str, False),
        "PreSignUp": (str, False),
        "PreTokenGeneration": (str, False),
        "UserMigration": (str, False),
        "VerifyAuthChallengeResponse": (str, False),
    }


class PasswordPolicy(AWSProperty):
    props = {
        "MinimumLength": (positive_integer, False),
        "RequireLowercase": (boolean, False),
        "RequireNumbers": (boolean, False),
        "RequireSymbols": (boolean, False),
        "RequireUppercase": (boolean, False),
        "TemporaryPasswordValidityDays": (positive_integer, False),
    }


class Policies(AWSProperty):
    props = {
        "PasswordPolicy": (PasswordPolicy, False),
    }


class NumberAttributeConstraints(AWSProperty):
    props = {
        "MaxValue": (str, False),
        "MinValue": (str, False),
    }


class StringAttributeConstraints(AWSProperty):
    props = {
        "MaxLength": (str, False),
        "MinLength": (str, False),
    }


class SchemaAttribute(AWSProperty):
    props = {
        "AttributeDataType": (str, False),
        "DeveloperOnlyAttribute": (boolean, False),
        "Mutable": (boolean, False),
        "Name": (str, False),
        "NumberAttributeConstraints": (NumberAttributeConstraints, False),
        "StringAttributeConstraints": (StringAttributeConstraints, False),
        "Required": (boolean, False),
    }


class SmsConfiguration(AWSProperty):
    props = {
        "ExternalId": (str, False),
        "SnsCallerArn": (str, True),
    }


class UserPoolAddOns(AWSProperty):
    props = {
        "AdvancedSecurityMode": (str, False),
    }


class VerificationMessageTemplate(AWSProperty):
    props = {
        "DefaultEmailOption": (str, False),
        "EmailMessage": (str, False),
        "EmailMessageByLink": (str, False),
        "EmailSubject": (str, False),
        "EmailSubjectByLink": (str, False),
        "SmsMessage": (str, False),
    }


class RecoveryOption(AWSProperty):
    props = {
        "Name": (validate_recoveryoption_name, False),
        "Priority": (positive_integer, False),
    }


class AccountRecoverySetting(AWSProperty):
    props = {"RecoveryMechanisms": ([RecoveryOption], False)}


class UsernameConfiguration(AWSProperty):
    props = {
        "CaseSensitive": (boolean, False),
    }


class UserPool(AWSObject):
    resource_type = "AWS::Cognito::UserPool"

    props = {
        "AccountRecoverySetting": (AccountRecoverySetting, False),
        "AdminCreateUserConfig": (AdminCreateUserConfig, False),
        "AliasAttributes": ([str], False),
        "AutoVerifiedAttributes": ([str], False),
        "DeviceConfiguration": (DeviceConfiguration, False),
        "EmailConfiguration": (EmailConfiguration, False),
        "EmailVerificationMessage": (str, False),
        "EmailVerificationSubject": (str, False),
        "EnabledMfas": ([str], False),
        "LambdaConfig": (LambdaConfig, False),
        "MfaConfiguration": (str, False),
        "Policies": (Policies, False),
        "Schema": ([SchemaAttribute], False),
        "SmsAuthenticationMessage": (str, False),
        "SmsConfiguration": (SmsConfiguration, False),
        "SmsVerificationMessage": (str, False),
        "UserPoolAddOns": (UserPoolAddOns, False),
        "UserPoolName": (str, False),
        "UserPoolTags": (dict, False),
        "UsernameAttributes": ([str], False),
        "UsernameConfiguration": (UsernameConfiguration, False),
        "VerificationMessageTemplate": (VerificationMessageTemplate, False),
    }


class AnalyticsConfiguration(AWSProperty):
    props = {
        "ApplicationId": (str, False),
        "ExternalId": (str, False),
        "RoleArn": (str, False),
        "UserDataShared": (boolean, False),
    }


class TokenValidityUnits(AWSProperty):
    props = {
        "AccessToken": (str, False),
        "IdToken": (str, False),
        "RefreshToken": (str, False),
    }


class UserPoolClient(AWSObject):
    resource_type = "AWS::Cognito::UserPoolClient"

    props = {
        "AccessTokenValidity": (positive_integer, False),
        "AllowedOAuthFlows": ([str], False),
        "AllowedOAuthFlowsUserPoolClient": (boolean, False),
        "AllowedOAuthScopes": ([str], False),
        "AnalyticsConfiguration": (AnalyticsConfiguration, False),
        "CallbackURLs": ([str], False),
        "ClientName": (str, False),
        "DefaultRedirectURI": (str, False),
        "ExplicitAuthFlows": ([str], False),
        "GenerateSecret": (boolean, False),
        "IdTokenValidity": (positive_integer, False),
        "LogoutURLs": ([str], False),
        "PreventUserExistenceErrors": (str, False),
        "ReadAttributes": ([str], False),
        "RefreshTokenValidity": (positive_integer, False),
        "SupportedIdentityProviders": ([str], False),
        "TokenValidityUnits": (TokenValidityUnits, False),
        "UserPoolId": (str, True),
        "WriteAttributes": ([str], False),
    }


class CustomDomainConfigType(AWSProperty):
    props = {
        "CertificateArn": (str, False),
    }


class UserPoolDomain(AWSObject):
    resource_type = "AWS::Cognito::UserPoolDomain"

    props = {
        "CustomDomainConfig": (CustomDomainConfigType, False),
        "Domain": (str, True),
        "UserPoolId": (str, True),
    }


class UserPoolGroup(AWSObject):
    resource_type = "AWS::Cognito::UserPoolGroup"

    props = {
        "Description": (str, False),
        "GroupName": (str, True),
        "Precedence": (positive_integer, False),
        "RoleArn": (str, False),
        "UserPoolId": (str, True),
    }


class UserPoolIdentityProvider(AWSObject):
    resource_type = "AWS::Cognito::UserPoolIdentityProvider"

    props = {
        "AttributeMapping": (dict, False),
        "IdpIdentifiers": ([str], False),
        "ProviderDetails": (dict, False),
        "ProviderName": (str, True),
        "ProviderType": (str, True),
        "UserPoolId": (str, True),
    }


class ResourceServerScopeType(AWSProperty):
    props = {"ScopeDescription": (str, True), "ScopeName": (str, True)}


class UserPoolResourceServer(AWSObject):
    resource_type = "AWS::Cognito::UserPoolResourceServer"

    props = {
        "Identifier": (str, True),
        "Name": (str, True),
        "Scopes": ([ResourceServerScopeType], False),
        "UserPoolId": (str, True),
    }


class AccountTakeoverActionType(AWSProperty):
    props = {
        "EventAction": (str, True),
        "Notify": (boolean, True),
    }


class AccountTakeoverActionsType(AWSProperty):
    props = {
        "HighAction": (AccountTakeoverActionType, False),
        "LowAction": (AccountTakeoverActionType, False),
        "MediumAction": (AccountTakeoverActionType, False),
    }


class NotifyEmailType(AWSProperty):
    props = {
        "HtmlBody": (str, False),
        "Subject": (str, True),
        "TextBody": (str, False),
    }


class NotifyConfigurationType(AWSProperty):
    props = {
        "BlockEmail": (NotifyEmailType, False),
        "From": (str, False),
        "MfaEmail": (NotifyEmailType, False),
        "NoActionEmail": (NotifyEmailType, False),
        "ReplyTo": (str, False),
        "SourceArn": (str, True),
    }


class AccountTakeoverRiskConfigurationType(AWSProperty):
    props = {
        "Actions": (AccountTakeoverActionsType, True),
        "NotifyConfiguration": (NotifyConfigurationType, False),
    }


class CompromisedCredentialsActionsType(AWSProperty):
    props = {
        "EventAction": (str, True),
    }


class CompromisedCredentialsRiskConfigurationType(AWSProperty):
    props = {
        "Actions": (CompromisedCredentialsActionsType, True),
        "EventFilter": ([str], False),
    }


class RiskExceptionConfigurationType(AWSProperty):
    props = {
        "BlockedIPRangeList": ([str], False),
        "SkippedIPRangeList": ([str], False),
    }


class UserPoolRiskConfigurationAttachment(AWSObject):
    resource_type = "AWS::Cognito::UserPoolRiskConfigurationAttachment"

    props = {
        "AccountTakeoverRiskConfiguration": (
            AccountTakeoverRiskConfigurationType,
            False,
        ),
        "ClientId": (str, True),
        "CompromisedCredentialsRiskConfiguration": (
            CompromisedCredentialsRiskConfigurationType,
            False,
        ),
        "RiskExceptionConfiguration": (RiskExceptionConfigurationType, False),
        "UserPoolId": (str, True),
    }


class UserPoolUICustomizationAttachment(AWSObject):
    resource_type = "AWS::Cognito::UserPoolUICustomizationAttachment"

    props = {
        "CSS": (str, False),
        "ClientId": (str, True),
        "UserPoolId": (str, True),
    }


class AttributeType(AWSProperty):
    props = {
        "Name": (str, True),
        "Value": (str, False),
    }


class UserPoolUser(AWSObject):
    resource_type = "AWS::Cognito::UserPoolUser"

    props = {
        "ClientMetadata": (dict, False),
        "DesiredDeliveryMediums": ([str], False),
        "ForceAliasCreation": (boolean, False),
        "UserAttributes": ([AttributeType], False),
        "MessageAction": (str, False),
        "Username": (str, False),
        "UserPoolId": (str, True),
        "ValidationData": ([AttributeType], False),
    }


class UserPoolUserToGroupAttachment(AWSObject):
    resource_type = "AWS::Cognito::UserPoolUserToGroupAttachment"

    props = {
        "GroupName": (str, True),
        "Username": (str, True),
        "UserPoolId": (str, True),
    }



from troposphere import Template
from troposphere.firehose import (
    BufferingHints,
    CloudWatchLoggingOptions,
    CopyCommand,
    DeliveryStream,
    EncryptionConfiguration,
    KMSEncryptionConfig,
    RedshiftDestinationConfiguration,
    S3Configuration,
)

t = Template()
t.set_version("2010-09-09")
t.set_description("Sample Kinesis Firehose Delivery Stream")

t.add_resource(
    DeliveryStream(
        "MyDeliveryStream",
        DeliveryStreamName="MyDeliveryStream",
        RedshiftDestinationConfiguration=RedshiftDestinationConfiguration(
            CloudWatchLoggingOptions=CloudWatchLoggingOptions(
                Enabled=True,
                LogGroupName="my-log-group",
                LogStreamName="my-log-stream",
            ),
            ClusterJDBCURL="jdbc:redshift://my-redshift-db.asdf.us-west-2.redshift.amazonaws.com:5432/mydb",  # noqa
            CopyCommand=CopyCommand(
                CopyOptions="JSON 'auto'",
                DataTableColumns="mycol",
                DataTableName="mytable",
            ),
            Password="hooli-suxx",
            RoleARN="arn:aws:iam::12345:role/my-role",
            S3Configuration=S3Configuration(
                BucketARN="arn:aws:s3:::muh-bucket",
                BufferingHints=BufferingHints(
                    IntervalInSeconds=5,
                    SizeInMBs=60,
                ),
                CloudWatchLoggingOptions=CloudWatchLoggingOptions(
                    Enabled=True,
                    LogGroupName="my-other-log-group",
                    LogStreamName="my-other-log-stream",
                ),
                CompressionFormat="UNCOMPRESSED",
                EncryptionConfiguration=EncryptionConfiguration(
                    KMSEncryptionConfig=KMSEncryptionConfig(
                        AWSKMSKeyARN="aws-kms-key-arn"
                    ),
                    NoEncryptionConfig="NoEncryption",
                ),
                Prefix="my-prefix",
                RoleARN="arn:aws:iam::12345:role/my-role",
            ),
            Username="erlich_bachman",
        ),
    )
)

print(t.to_json())



from . import AWSObject, AWSProperty, Tags
from .validators import (
    boolean,
    double,
    ecs_efs_encryption_status,
    ecs_proxy_type,
    integer,
    integer_range,
    network_port,
    positive_integer,
)

LAUNCH_TYPE_EC2 = "EC2"
LAUNCH_TYPE_FARGATE = "FARGATE"

SCHEDULING_STRATEGY_REPLICA = "REPLICA"
SCHEDULING_STRATEGY_DAEMON = "DAEMON"


class ManagedScaling(AWSProperty):
    """
    Class for ManagedScaling for AutoScalingGroupProvider
    """

    props = {
        "MaximumScalingStepSize": (integer_range(1, 10000), False),
        "MinimumScalingStepSize": (integer_range(1, 10000), False),
        "Status": (str, False),
        "TargetCapacity": (integer_range(1, 100), False),
    }


class AutoScalingGroupProvider(AWSProperty):
    """
    Class for property AutoScalingGroupProvider in AWS::ECS::CpacityProvider
    """

    props = {
        "AutoScalingGroupArn": (str, True),
        "ManagedScaling": (ManagedScaling, False),
        "ManagedTerminationProtection": (str, False),
    }


class CapacityProvider(AWSObject):
    """
    Class for AWS::ECS::CpacityProvider
    """

    resource_type = "AWS::ECS::CapacityProvider"
    props = {
        "AutoScalingGroupProvider": (AutoScalingGroupProvider, True),
        "Name": (str, False),
        "Tags": (Tags, False),
    }


class CapacityProviderStrategyItem(AWSProperty):
    """
    Class for the AWS::ECS::Cluster-CapacityProviderStrategyItem
    """

    props = {
        "Base": (integer, False),
        "CapacityProvider": (str, False),
        "Weight": (integer, False),
    }


class ExecuteCommandLogConfiguration(AWSProperty):
    props = {
        "CloudWatchEncryptionEnabled": (boolean, False),
        "CloudWatchLogGroupName": (str, False),
        "S3BucketName": (str, False),
        "S3EncryptionEnabled": (boolean, False),
        "S3KeyPrefix": (str, False),
    }


class ExecuteCommandConfiguration(AWSProperty):
    props = {
        "KmsKeyId": (str, False),
        "LogConfiguration": (ExecuteCommandLogConfiguration, False),
        "Logging": (str, False),
    }


class ClusterConfiguration(AWSProperty):
    props = {
        "ExecuteCommandConfiguration": (ExecuteCommandConfiguration, False),
    }


class ClusterSetting(AWSProperty):
    props = {
        "Name": (str, True),
        "Value": (str, True),
    }


class Cluster(AWSObject):
    resource_type = "AWS::ECS::Cluster"

    props = {
        "CapacityProviders": ([str], False),
        "ClusterName": (str, False),
        "ClusterSettings": ([ClusterSetting], False),
        "Configuration": (ClusterConfiguration, False),
        "DefaultCapacityProviderStrategy": ([CapacityProviderStrategyItem], False),
        "Tags": (Tags, False),
    }


class CapacityProviderStrategy(AWSProperty):
    props = {
        "Base": (integer, False),
        "CapacityProvider": (str, True),
        "Weight": (integer, False),
    }


class ClusterCapacityProviderAssociations(AWSObject):
    resource_type = "AWS::ECS::ClusterCapacityProviderAssociations"

    props = {
        "CapacityProviders": ([str], True),
        "Cluster": (str, True),
        "DefaultCapacityProviderStrategy": ([CapacityProviderStrategy], True),
    }


class PrimaryTaskSet(AWSObject):
    resource_type = "AWS::ECS::PrimaryTaskSet"

    props = {
        "Cluster": (str, True),
        "Service": (str, True),
        "TaskSetId": (str, True),
    }


class LoadBalancer(AWSProperty):
    props = {
        "ContainerName": (str, False),
        "ContainerPort": (network_port, True),
        "LoadBalancerName": (str, False),
        "TargetGroupArn": (str, False),
    }


class DeploymentCircuitBreaker(AWSProperty):
    """
    Property for AWS::ECS::Service DeploymentCircuitBreaker
    """

    props = {"Enable": (boolean, True), "Rollback": (boolean, True)}


class DeploymentConfiguration(AWSProperty):
    props = {
        "DeploymentCircuitBreaker": (DeploymentCircuitBreaker, False),
        "MaximumPercent": (positive_integer, False),
        "MinimumHealthyPercent": (positive_integer, False),
    }


class DeploymentController(AWSProperty):
    props = {
        "Type": (str, False),
    }


def placement_strategy_validator(x):
    valid_values = ["random", "spread", "binpack"]
    if x not in valid_values:
        raise ValueError(
            "Placement Strategy type must be one of: %s" % ", ".join(valid_values)
        )
    return x


def placement_constraint_validator(x):
    valid_values = ["distinctInstance", "memberOf"]
    if x not in valid_values:
        raise ValueError(
            "Placement Constraint type must be one of: %s" % ", ".join(valid_values)
        )
    return x


def scope_validator(x):
    valid_values = ["shared", "task"]
    if x not in valid_values:
        raise ValueError("Scope type must be one of: %s" % ", ".join(valid_values))
    return x


class PlacementConstraint(AWSProperty):
    props = {
        "Type": (placement_constraint_validator, True),
        "Expression": (str, False),
    }


class PlacementStrategy(AWSProperty):
    props = {
        "Type": (placement_strategy_validator, True),
        "Field": (str, False),
    }


class AwsvpcConfiguration(AWSProperty):
    props = {
        "AssignPublicIp": (str, False),
        "SecurityGroups": (list, False),
        "Subnets": (list, True),
    }


class NetworkConfiguration(AWSProperty):
    props = {
        "AwsvpcConfiguration": (AwsvpcConfiguration, False),
    }


def launch_type_validator(x):
    valid_values = [LAUNCH_TYPE_EC2, LAUNCH_TYPE_FARGATE]
    if x not in valid_values:
        raise ValueError("Launch Type must be one of: %s" % ", ".join(valid_values))
    return x


class ServiceRegistry(AWSProperty):
    props = {
        "ContainerName": (str, False),
        "ContainerPort": (integer, False),
        "Port": (integer, False),
        "RegistryArn": (str, False),
    }


class Service(AWSObject):
    resource_type = "AWS::ECS::Service"

    props = {
        "CapacityProviderStrategy": ([CapacityProviderStrategyItem], False),
        "Cluster": (str, False),
        "DeploymentConfiguration": (DeploymentConfiguration, False),
        "DeploymentController": (DeploymentController, False),
        "DesiredCount": (positive_integer, False),
        "EnableECSManagedTags": (boolean, False),
        "EnableExecuteCommand": (boolean, False),
        "HealthCheckGracePeriodSeconds": (positive_integer, False),
        "LaunchType": (launch_type_validator, False),
        "LoadBalancers": ([LoadBalancer], False),
        "NetworkConfiguration": (NetworkConfiguration, False),
        "Role": (str, False),
        "PlacementConstraints": ([PlacementConstraint], False),
        "PlacementStrategies": ([PlacementStrategy], False),
        "PlatformVersion": (str, False),
        "PropagateTags": (str, False),
        "SchedulingStrategy": (str, False),
        "ServiceName": (str, False),
        "ServiceRegistries": ([ServiceRegistry], False),
        "Tags": (Tags, False),
        "TaskDefinition": (str, True),
    }


class Environment(AWSProperty):
    props = {
        "Name": (str, True),
        "Value": (str, True),
    }


class MountPoint(AWSProperty):
    props = {
        "ContainerPath": (str, True),
        "SourceVolume": (str, True),
        "ReadOnly": (boolean, False),
    }


class PortMapping(AWSProperty):
    props = {
        "ContainerPort": (network_port, True),
        "HostPort": (network_port, False),
        "Protocol": (str, False),
    }


class VolumesFrom(AWSProperty):
    props = {
        "SourceContainer": (str, True),
        "ReadOnly": (boolean, False),
    }


class HostEntry(AWSProperty):
    props = {
        "Hostname": (str, True),
        "IpAddress": (str, True),
    }


class Device(AWSProperty):
    props = {
        "ContainerPath": (str, False),
        "HostPath": (str, False),
        "Permissions": ([str], False),
    }


class FirelensConfiguration(AWSProperty):
    props = {
        "Options": (dict, False),
        "Type": (str, True),
    }


class HealthCheck(AWSProperty):
    props = {
        "Command": ([str], True),
        "Interval": (integer, False),
        "Retries": (integer, False),
        "StartPeriod": (integer, False),
        "Timeout": (integer, False),
    }


class KernelCapabilities(AWSProperty):
    props = {
        "Add": ([str], False),
        "Drop": ([str], False),
    }


class Tmpfs(AWSProperty):
    props = {
        "ContainerPath": (str, False),
        "MountOptions": ([str], False),
        "Size": (integer, False),
    }


class LinuxParameters(AWSProperty):
    props = {
        "Capabilities": (KernelCapabilities, False),
        "Devices": ([Device], False),
        "InitProcessEnabled": (boolean, False),
        "SharedMemorySize": (integer, False),
        "Tmpfs": ([Tmpfs], False),
    }


class Secret(AWSProperty):
    props = {
        "Name": (str, True),
        "ValueFrom": (str, True),
    }


class LogConfiguration(AWSProperty):
    props = {
        "LogDriver": (str, True),
        "Options": (dict, False),
        "SecretOptions": ([Secret], False),
    }


class RepositoryCredentials(AWSProperty):
    props = {"CredentialsParameter": (str, False)}


class ResourceRequirement(AWSProperty):
    props = {
        "Type": (str, True),
        "Value": (str, True),
    }


class SystemControl(AWSProperty):
    props = {
        "Namespace": (str, True),
        "Value": (str, True),
    }


class Ulimit(AWSProperty):
    props = {
        "HardLimit": (integer, True),
        "Name": (str, True),
        "SoftLimit": (integer, True),
    }


class ContainerDependency(AWSProperty):
    props = {"Condition": (str, True), "ContainerName": (str, True)}


class EnvironmentFile(AWSProperty):
    props = {
        "Type": (str, False),
        "Value": (str, False),
    }


class ContainerDefinition(AWSProperty):
    props = {
        "Command": ([str], False),
        "Cpu": (integer, False),
        "DependsOn": ([ContainerDependency], False),
        "DisableNetworking": (boolean, False),
        "DnsSearchDomains": ([str], False),
        "DnsServers": ([str], False),
        "DockerLabels": (dict, False),
        "DockerSecurityOptions": ([str], False),
        "EntryPoint": ([str], False),
        "Environment": ([Environment], False),
        "EnvironmentFiles": ([EnvironmentFile], False),
        "Essential": (boolean, False),
        "ExtraHosts": ([HostEntry], False),
        "FirelensConfiguration": (FirelensConfiguration, False),
        "HealthCheck": (HealthCheck, False),
        "Hostname": (str, False),
        "Image": (str, False),
        "Interactive": (boolean, False),
        "Links": ([str], False),
        "LinuxParameters": (LinuxParameters, False),
        "LogConfiguration": (LogConfiguration, False),
        "Memory": (integer, False),
        "MemoryReservation": (integer, False),
        "MountPoints": ([MountPoint], False),
        "Name": (str, False),
        "PortMappings": ([PortMapping], False),
        "Privileged": (boolean, False),
        "PseudoTerminal": (boolean, False),
        "ReadonlyRootFilesystem": (boolean, False),
        "RepositoryCredentials": (RepositoryCredentials, False),
        "ResourceRequirements": ([ResourceRequirement], False),
        "Secrets": ([Secret], False),
        "StartTimeout": (integer, False),
        "StopTimeout": (integer, False),
        "SystemControls": ([SystemControl], False),
        "Ulimits": ([Ulimit], False),
        "User": (str, False),
        "VolumesFrom": ([VolumesFrom], False),
        "WorkingDirectory": (str, False),
    }


class Host(AWSProperty):
    props = {
        "SourcePath": (str, False),
    }


class DockerVolumeConfiguration(AWSProperty):
    props = {
        "Autoprovision": (boolean, False),
        "Driver": (str, False),
        "DriverOpts": (dict, False),
        "Labels": (dict, False),
        "Scope": (scope_validator, False),
    }


class AuthorizationConfig(AWSProperty):
    props = {"AccessPointId": (str, False), "IAM": (str, False)}


class EFSVolumeConfiguration(AWSProperty):
    props = {
        "AuthorizationConfig": (AuthorizationConfig, False),
        "FilesystemId": (str, True),
        "RootDirectory": (str, False),
        "TransitEncryption": (ecs_efs_encryption_status, False),
        "TransitEncryptionPort": (integer_range(1, (2 ** 16) - 1), False),
    }


class Volume(AWSProperty):
    props = {
        "DockerVolumeConfiguration": (DockerVolumeConfiguration, False),
        "Name": (str, True),
        "Host": (Host, False),
        "EFSVolumeConfiguration": (EFSVolumeConfiguration, False),
    }


class InferenceAccelerator(AWSProperty):
    props = {
        "DeviceName": (str, False),
        "DeviceType": (str, False),
    }


class ProxyConfiguration(AWSProperty):
    props = {
        "ContainerName": (str, True),
        "ProxyConfigurationProperties": (list, False),
        "Type": (ecs_proxy_type, False),
    }


class EphemeralStorage(AWSProperty):
    props = {
        "SizeInGiB": (integer_range(21, 200), False),
    }


class TaskDefinition(AWSObject):
    resource_type = "AWS::ECS::TaskDefinition"

    props = {
        "ContainerDefinitions": ([ContainerDefinition], False),
        "Cpu": (str, False),
        "EphemeralStorage": (EphemeralStorage, False),
        "ExecutionRoleArn": (str, False),
        "Family": (str, False),
        "InferenceAccelerators": ([InferenceAccelerator], False),
        "IpcMode": (str, False),
        "Memory": (str, False),
        "NetworkMode": (str, False),
        "PidMode": (str, False),
        "PlacementConstraints": ([PlacementConstraint], False),
        "ProxyConfiguration": (ProxyConfiguration, False),
        "RequiresCompatibilities": ([str], False),
        "Tags": (Tags, False),
        "TaskRoleArn": (str, False),
        "Volumes": ([Volume], False),
    }


class Scale(AWSProperty):
    props = {
        "Unit": (str, False),
        "Value": (double, False),
    }


class TaskSet(AWSObject):
    resource_type = "AWS::ECS::TaskSet"

    props = {
        "Cluster": (str, True),
        "ExternalId": (str, False),
        "LaunchType": (str, False),
        "LoadBalancers": ([LoadBalancer], False),
        "NetworkConfiguration": (NetworkConfiguration, False),
        "PlatformVersion": (str, False),
        "Scale": (Scale, False),
        "Service": (str, True),
        "ServiceRegistries": ([ServiceRegistry], False),
        "TaskDefinition": (str, True),
    }



# Copyright (c) 2012-2017, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject, AWSProperty, Tags
from .validators import boolean, double, integer, integer_range, positive_integer


class CsvClassifier(AWSProperty):
    props = {
        "AllowSingleColumn": (boolean, False),
        "ContainsHeader": (str, False),
        "Delimiter": (str, False),
        "DisableValueTrimming": (boolean, False),
        "Header": ([str], False),
        "Name": (str, False),
        "QuoteSymbol": (str, False),
    }


class GrokClassifier(AWSProperty):
    props = {
        "Classification": (str, True),
        "CustomPatterns": (str, False),
        "GrokPattern": (str, True),
        "Name": (str, False),
    }


class JsonClassifier(AWSProperty):
    props = {
        "JsonPath": (str, True),
        "Name": (str, False),
    }


class XMLClassifier(AWSProperty):
    props = {
        "Classification": (str, True),
        "Name": (str, False),
        "RowTag": (str, True),
    }


class Classifier(AWSObject):
    resource_type = "AWS::Glue::Classifier"

    props = {
        "CsvClassifier": (CsvClassifier, False),
        "GrokClassifier": (GrokClassifier, False),
        "JsonClassifier": (JsonClassifier, False),
        "XMLClassifier": (XMLClassifier, False),
    }


class PhysicalConnectionRequirements(AWSProperty):
    props = {
        "AvailabilityZone": (str, False),
        "SecurityGroupIdList": ([str], False),
        "SubnetId": (str, False),
    }


def connection_type_validator(type):
    valid_types = [
        "CUSTOM",
        "JDBC",
        "KAFKA",
        "MARKETPLACE",
        "MONGODB",
        "NETWORK",
        "SFTP",
    ]
    if type not in valid_types:
        raise ValueError("% is not a valid value for ConnectionType" % type)
    return type


class ConnectionInput(AWSProperty):
    props = {
        "ConnectionProperties": (dict, True),
        "ConnectionType": (connection_type_validator, True),
        "Description": (str, False),
        "MatchCriteria": ([str], False),
        "Name": (str, False),
        "PhysicalConnectionRequirements": (PhysicalConnectionRequirements, False),
    }


class Connection(AWSObject):
    resource_type = "AWS::Glue::Connection"

    props = {
        "CatalogId": (str, True),
        "ConnectionInput": (ConnectionInput, True),
    }


class Schedule(AWSProperty):
    props = {
        "ScheduleExpression": (str, False),
    }


def delete_behavior_validator(value):
    valid_values = [
        "LOG",
        "DELETE_FROM_DATABASE",
        "DEPRECATE_IN_DATABASE",
    ]
    if value not in valid_values:
        raise ValueError("% is not a valid value for DeleteBehavior" % value)
    return value


def update_behavior_validator(value):
    valid_values = [
        "LOG",
        "UPDATE_IN_DATABASE",
    ]
    if value not in valid_values:
        raise ValueError("% is not a valid value for UpdateBehavior" % value)
    return value


class SchemaChangePolicy(AWSProperty):
    props = {
        "DeleteBehavior": (delete_behavior_validator, False),
        "UpdateBehavior": (update_behavior_validator, False),
    }


class CatalogTarget(AWSProperty):
    props = {
        "DatabaseName": (str, False),
        "Tables": ([str], False),
    }


class DynamoDBTarget(AWSProperty):
    props = {
        "Path": (str, False),
    }


class JdbcTarget(AWSProperty):
    props = {
        "ConnectionName": (str, False),
        "Exclusions": ([str], False),
        "Path": (str, False),
    }


class S3Target(AWSProperty):
    props = {
        "Exclusions": ([str], False),
        "Path": (str, False),
    }


class Targets(AWSProperty):
    props = {
        "CatalogTargets": ([CatalogTarget], False),
        "DynamoDBTargets": ([DynamoDBTarget], False),
        "JdbcTargets": ([JdbcTarget], False),
        "S3Targets": ([S3Target], False),
    }


class Crawler(AWSObject):
    resource_type = "AWS::Glue::Crawler"

    props = {
        "Classifiers": ([str], False),
        "Configuration": (str, False),
        "CrawlerSecurityConfiguration": (str, False),
        "DatabaseName": (str, True),
        "Description": (str, False),
        "Name": (str, False),
        "Role": (str, True),
        "Schedule": (Schedule, False),
        "SchemaChangePolicy": (SchemaChangePolicy, False),
        "TablePrefix": (str, False),
        "Tags": (dict, False),
        "Targets": (Targets, True),
    }


class ConnectionPasswordEncryption(AWSProperty):
    props = {
        "KmsKeyId": (str, False),
        "ReturnConnectionPasswordEncrypted": (boolean, False),
    }


class EncryptionAtRest(AWSProperty):
    props = {
        "CatalogEncryptionMode": (str, False),
        "SseAwsKmsKeyId": (str, False),
    }


class DataCatalogEncryptionSettingsProperty(AWSProperty):
    props = {
        "ConnectionPasswordEncryption": (ConnectionPasswordEncryption, False),
        "EncryptionAtRest": (EncryptionAtRest, False),
    }


class DataCatalogEncryptionSettings(AWSObject):
    resource_type = "AWS::Glue::DataCatalogEncryptionSettings"

    props = {
        "CatalogId": (str, True),
        "DataCatalogEncryptionSettings": (DataCatalogEncryptionSettingsProperty, True),
    }


class DatabaseInput(AWSProperty):
    props = {
        "Description": (str, False),
        "LocationUri": (str, False),
        "Name": (str, False),
        "Parameters": (dict, False),
    }


class Database(AWSObject):
    resource_type = "AWS::Glue::Database"

    props = {
        "CatalogId": (str, True),
        "DatabaseInput": (DatabaseInput, True),
    }


class DevEndpoint(AWSObject):
    resource_type = "AWS::Glue::DevEndpoint"

    props = {
        "Arguments": (dict, False),
        "EndpointName": (str, False),
        "ExtraJarsS3Path": (str, False),
        "ExtraPythonLibsS3Path": (str, False),
        "GlueVersion": (str, False),
        "NumberOfNodes": (integer, False),
        "NumberOfWorkers": (integer, False),
        "PublicKey": (str, False),
        "PublicKeys": ([str], False),
        "RoleArn": (str, True),
        "SecurityConfiguration": (str, False),
        "SecurityGroupIds": ([str], False),
        "SubnetId": (str, False),
        "Tags": (dict, False),
        "WorkerType": (str, False),
    }


class ConnectionsList(AWSProperty):
    props = {
        "Connections": ([str], False),
    }


class ExecutionProperty(AWSProperty):
    props = {
        "MaxConcurrentRuns": (positive_integer, False),
    }


class JobCommand(AWSProperty):
    props = {
        "Name": (str, False),
        "PythonVersion": (str, False),
        "ScriptLocation": (str, False),
    }


class NotificationProperty(AWSProperty):
    props = {
        "NotifyDelayAfter": (integer, False),
    }


class Job(AWSObject):
    resource_type = "AWS::Glue::Job"

    props = {
        "AllocatedCapacity": (double, False),
        "Command": (JobCommand, True),
        "Connections": (ConnectionsList, False),
        "DefaultArguments": (dict, False),
        "Description": (str, False),
        "ExecutionProperty": (ExecutionProperty, False),
        "GlueVersion": (str, False),
        "LogUri": (str, False),
        "MaxCapacity": (double, False),
        "MaxRetries": (double, False),
        "Name": (str, False),
        "NotificationProperty": (NotificationProperty, False),
        "NumberOfWorkers": (integer, False),
        "Role": (str, True),
        "SecurityConfiguration": (str, False),
        "Tags": (dict, False),
        "Timeout": (integer, False),
        "WorkerType": (str, False),
    }


class GlueTables(AWSProperty):
    props = {
        "CatalogId": (str, False),
        "ConnectionName": (str, False),
        "DatabaseName": (str, True),
        "TableName": (str, True),
    }


class InputRecordTables(AWSProperty):
    props = {
        "GlueTables": ([GlueTables], False),
    }


class FindMatchesParameters(AWSProperty):
    props = {
        "AccuracyCostTradeoff": (float, False),
        "EnforceProvidedLabels": (boolean, False),
        "PrecisionRecallTradeoff": (float, False),
        "PrimaryKeyColumnName": (str, True),
    }


class TransformParameters(AWSProperty):
    props = {
        "FindMatchesParameters": (FindMatchesParameters, False),
        "TransformType": (str, True),
    }


class MLTransform(AWSObject):
    resource_type = "AWS::Glue::MLTransform"

    props = {
        "Description": (str, False),
        "GlueVersion": (str, False),
        "InputRecordTables": (InputRecordTables, True),
        "MaxCapacity": (double, False),
        "MaxRetries": (integer, False),
        "Name": (str, False),
        "NumberOfWorkers": (integer, False),
        "Role": (str, True),
        "Tags": (dict, False),
        "Timeout": (integer, False),
        "TransformParameters": (TransformParameters, True),
        "WorkerType": (str, False),
    }


class Column(AWSProperty):
    props = {
        "Comment": (str, False),
        "Name": (str, True),
        "Type": (str, False),
    }


class Order(AWSProperty):
    props = {
        "Column": (str, True),
        "SortOrder": (integer_range(0, 1), False),
    }


class SerdeInfo(AWSProperty):
    props = {
        "Name": (str, False),
        "Parameters": (dict, False),
        "SerializationLibrary": (str, False),
    }


class SkewedInfo(AWSProperty):
    props = {
        "SkewedColumnNames": ([str], False),
        "SkewedColumnValues": ([str], False),
        "SkewedColumnValueLocationMaps": (dict, False),
    }


class StorageDescriptor(AWSProperty):
    props = {
        "BucketColumns": ([str], False),
        "Columns": ([Column], False),
        "Compressed": (boolean, False),
        "InputFormat": (str, False),
        "Location": (str, False),
        "NumberOfBuckets": (positive_integer, False),
        "OutputFormat": (str, False),
        "Parameters": (dict, False),
        "SerdeInfo": (SerdeInfo, False),
        "SkewedInfo": (SkewedInfo, False),
        "SortColumns": ([Order], False),
        "StoredAsSubDirectories": (boolean, False),
    }


class PartitionInput(AWSProperty):
    props = {
        "Parameters": (dict, False),
        "StorageDescriptor": (StorageDescriptor, False),
        "Values": ([str], True),
    }


class Partition(AWSObject):
    resource_type = "AWS::Glue::Partition"

    props = {
        "CatalogId": (str, True),
        "DatabaseName": (str, True),
        "PartitionInput": (PartitionInput, True),
        "TableName": (str, True),
    }


class Registry(AWSObject):
    resource_type = "AWS::Glue::Registry"

    props = {
        "Description": (str, False),
        "Name": (str, True),
        "Tags": (Tags, False),
    }


class SchemaVersion(AWSProperty):
    props = {
        "IsLatest": (boolean, False),
        "VersionNumber": (integer, False),
    }


class Schema(AWSObject):
    resource_type = "AWS::Glue::Schema"

    props = {
        "CheckpointVersion": (SchemaVersion, False),
        "Compatibility": (str, True),
        "DataFormat": (str, True),
        "Description": (str, False),
        "Name": (str, True),
        "Registry": (Registry, False),
        "SchemaDefinition": (str, True),
        "Tags": (Tags, False),
    }


class SchemaVersionMetadata(AWSObject):
    resource_type = "AWS::Glue::SchemaVersionMetadata"

    props = {
        "Key": (str, True),
        "SchemaVersionId": (str, True),
        "Value": (str, True),
    }


class CloudWatchEncryption(AWSProperty):
    props = {
        "CloudWatchEncryptionMode": (str, False),
        "KmsKeyArn": (str, False),
    }


class JobBookmarksEncryption(AWSProperty):
    props = {
        "JobBookmarksEncryptionMode": (str, False),
        "KmsKeyArn": (str, False),
    }


class S3Encryption(AWSProperty):
    props = {
        "KmsKeyArn": (str, False),
        "S3EncryptionMode": (str, False),
    }


class EncryptionConfiguration(AWSProperty):
    props = {
        "CloudWatchEncryption": (CloudWatchEncryption, False),
        "JobBookmarksEncryption": (JobBookmarksEncryption, False),
        "S3Encryptions": ([S3Encryption], False),
    }


class SecurityConfiguration(AWSObject):
    resource_type = "AWS::Glue::SecurityConfiguration"

    props = {
        "EncryptionConfiguration": (EncryptionConfiguration, True),
        "Name": (str, True),
    }


def table_type_validator(type):
    valid_types = [
        "EXTERNAL_TABLE",
        "VIRTUAL_VIEW",
    ]
    if type not in valid_types:
        raise ValueError("% is not a valid value for TableType" % type)
    return type


class TableInput(AWSProperty):
    props = {
        "Description": (str, False),
        "Name": (str, False),
        "Owner": (str, False),
        "Parameters": (dict, False),
        "PartitionKeys": ([Column], False),
        "Retention": (positive_integer, False),
        "StorageDescriptor": (StorageDescriptor, False),
        "TableType": (table_type_validator, False),
        "ViewExpandedText": (str, False),
        "ViewOriginalText": (str, False),
    }


class Table(AWSObject):
    resource_type = "AWS::Glue::Table"

    props = {
        "CatalogId": (str, True),
        "DatabaseName": (str, True),
        "TableInput": (TableInput, True),
    }


class Action(AWSProperty):
    props = {
        "Arguments": (dict, False),
        "CrawlerName": (str, False),
        "JobName": (str, False),
        "SecurityConfiguration": (str, False),
    }


class Condition(AWSProperty):
    props = {
        "CrawlerName": (str, False),
        "CrawlState": (str, False),
        "JobName": (str, False),
        "LogicalOperator": (str, False),
        "State": (str, False),
    }


class Predicate(AWSProperty):
    props = {
        "Conditions": ([Condition], False),
        "Logical": (str, False),
    }


def trigger_type_validator(type):
    valid_types = [
        "SCHEDULED",
        "CONDITIONAL",
        "ON_DEMAND",
    ]
    if type not in valid_types:
        raise ValueError("% is not a valid value for Type" % type)
    return type


class Trigger(AWSObject):
    resource_type = "AWS::Glue::Trigger"

    props = {
        "Actions": ([Action], True),
        "Description": (str, False),
        "Name": (str, False),
        "Predicate": (Predicate, False),
        "Schedule": (str, False),
        "StartOnCreation": (boolean, False),
        "Tags": (dict, False),
        "Type": (str, True),
        "WorkflowName": (str, False),
    }


class Workflow(AWSObject):
    resource_type = "AWS::Glue::Workflow"

    props = {
        "DefaultRunProperties": (dict, False),
        "Description": (str, False),
        "Name": (str, False),
        "Tags": (dict, False),
    }



# Copyright (c) 2012-2017, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject, AWSProperty
from .validators import integer


class InputParallelism(AWSProperty):
    props = {
        "Count": (integer, True),
    }


class RecordColumn(AWSProperty):
    props = {
        "Mapping": (str, False),
        "Name": (str, True),
        "SqlType": (str, True),
    }


class CSVMappingParameters(AWSProperty):
    props = {
        "RecordColumnDelimiter": (str, True),
        "RecordRowDelimiter": (str, True),
    }


class JSONMappingParameters(AWSProperty):
    props = {
        "RecordRowPath": (str, True),
    }


class MappingParameters(AWSProperty):
    props = {
        "CSVMappingParameters": (CSVMappingParameters, False),
        "JSONMappingParameters": (JSONMappingParameters, False),
    }


class RecordFormat(AWSProperty):
    props = {
        "MappingParameters": (MappingParameters, False),
        "RecordFormatType": (str, True),
    }


class InputSchema(AWSProperty):
    props = {
        "RecordColumns": ([RecordColumn], True),
        "RecordEncoding": (str, False),
        "RecordFormat": (RecordFormat, True),
    }


class KinesisFirehoseInput(AWSProperty):
    props = {
        "ResourceARN": (str, True),
        "RoleARN": (str, True),
    }


class KinesisStreamsInput(AWSProperty):
    props = {
        "ResourceARN": (str, True),
        "RoleARN": (str, True),
    }


class InputLambdaProcessor(AWSProperty):
    props = {
        "ResourceARN": (str, True),
        "RoleARN": (str, True),
    }


class InputProcessingConfiguration(AWSProperty):
    props = {
        "InputLambdaProcessor": (InputLambdaProcessor, False),
    }


class Input(AWSProperty):
    props = {
        "NamePrefix": (str, True),
        "InputParallelism": (InputParallelism, False),
        "InputSchema": (InputSchema, True),
        "KinesisFirehoseInput": (KinesisFirehoseInput, False),
        "KinesisStreamsInput": (KinesisStreamsInput, False),
        "InputProcessingConfiguration": (InputProcessingConfiguration, False),
    }


class Application(AWSObject):
    resource_type = "AWS::KinesisAnalytics::Application"

    props = {
        "ApplicationName": (str, False),
        "ApplicationDescription": (str, False),
        "ApplicationCode": (str, False),
        "Inputs": ([Input], True),
    }


class DestinationSchema(AWSProperty):
    props = {
        "RecordFormatType": (str, False),
    }


class KinesisFirehoseOutput(AWSProperty):
    props = {
        "ResourceARN": (str, True),
        "RoleARN": (str, True),
    }


class KinesisStreamsOutput(AWSProperty):
    props = {
        "ResourceARN": (str, True),
        "RoleARN": (str, True),
    }


class LambdaOutput(AWSProperty):
    props = {
        "ResourceARN": (str, True),
        "RoleARN": (str, True),
    }


class Output(AWSProperty):
    props = {
        "DestinationSchema": (DestinationSchema, True),
        "KinesisFirehoseOutput": (KinesisFirehoseOutput, False),
        "KinesisStreamsOutput": (KinesisStreamsOutput, False),
        "LambdaOutput": (LambdaOutput, False),
        "Name": (str, True),
    }


class ApplicationOutput(AWSObject):
    resource_type = "AWS::KinesisAnalytics::ApplicationOutput"

    props = {
        "ApplicationName": (str, True),
        "Output": (Output, True),
    }


class ReferenceSchema(AWSProperty):
    props = {
        "RecordColumns": ([RecordColumn], True),
        "RecordEncoding": (str, False),
        "RecordFormat": (RecordFormat, True),
    }


class S3ReferenceDataSource(AWSProperty):
    props = {
        "BucketARN": (str, False),
        "FileKey": (str, False),
        "ReferenceRoleARN": (str, False),
    }


class ReferenceDataSource(AWSProperty):
    props = {
        "ReferenceSchema": (ReferenceSchema, True),
        "S3ReferenceDataSource": (S3ReferenceDataSource, False),
        "TableName": (str, False),
    }


class ApplicationReferenceDataSource(AWSObject):
    resource_type = "AWS::KinesisAnalytics::ApplicationReferenceDataSource"

    props = {
        "ApplicationName": (str, True),
        "ReferenceDataSource": (ReferenceDataSource, True),
    }



# Copyright (c) 2012-2019, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 5.3.0


from . import AWSObject, AWSProperty
from .validators import integer


class MemberFabricConfiguration(AWSProperty):
    props = {
        "AdminPassword": (str, True),
        "AdminUsername": (str, True),
    }


class MemberFrameworkConfiguration(AWSProperty):
    props = {
        "MemberFabricConfiguration": (MemberFabricConfiguration, False),
    }


class MemberConfiguration(AWSProperty):
    props = {
        "Description": (str, False),
        "MemberFrameworkConfiguration": (MemberFrameworkConfiguration, False),
        "Name": (str, True),
    }


class NetworkFabricConfiguration(AWSProperty):
    props = {
        "Edition": (str, True),
    }


class NetworkFrameworkConfiguration(AWSProperty):
    props = {
        "NetworkFabricConfiguration": (NetworkFabricConfiguration, False),
    }


class ApprovalThresholdPolicy(AWSProperty):
    props = {
        "ProposalDurationInHours": (integer, False),
        "ThresholdComparator": (str, False),
        "ThresholdPercentage": (integer, False),
    }


class VotingPolicy(AWSProperty):
    props = {
        "ApprovalThresholdPolicy": (ApprovalThresholdPolicy, False),
    }


class NetworkConfiguration(AWSProperty):
    props = {
        "Description": (str, False),
        "Framework": (str, True),
        "FrameworkVersion": (str, True),
        "Name": (str, True),
        "NetworkFrameworkConfiguration": (NetworkFrameworkConfiguration, False),
        "VotingPolicy": (VotingPolicy, True),
    }


class Member(AWSObject):
    resource_type = "AWS::ManagedBlockchain::Member"

    props = {
        "InvitationId": (str, False),
        "MemberConfiguration": (MemberConfiguration, True),
        "NetworkConfiguration": (NetworkConfiguration, False),
        "NetworkId": (str, False),
    }


class NodeConfiguration(AWSProperty):
    props = {
        "AvailabilityZone": (str, True),
        "InstanceType": (str, True),
    }


class Node(AWSObject):
    resource_type = "AWS::ManagedBlockchain::Node"

    props = {
        "MemberId": (str, True),
        "NetworkId": (str, True),
        "NodeConfiguration": (NodeConfiguration, True),
    }



# Copyright (c) 2012-2017, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject, AWSProperty
from .validators import boolean, integer


class Detector(AWSObject):
    resource_type = "AWS::GuardDuty::Detector"

    props = {
        "Enable": (boolean, True),
        "FindingPublishingFrequency": (str, False),
    }


class Condition(AWSProperty):
    props = {
        "Eq": ([str], False),
        "Gte": (integer, False),
        "Lt": (integer, False),
        "Lte": (integer, False),
        "Neq": ([str], False),
    }


class FindingCriteria(AWSProperty):
    props = {
        "Criterion": (dict, False),
        "ItemType": (Condition, False),
    }


class Filter(AWSObject):
    resource_type = "AWS::GuardDuty::Filter"

    props = {
        "Action": (str, True),
        "Description": (str, True),
        "DetectorId": (str, True),
        "FindingCriteria": (FindingCriteria, True),
        "Name": (str, False),
        "Rank": (integer, True),
    }


class IPSet(AWSObject):
    resource_type = "AWS::GuardDuty::IPSet"

    props = {
        "Activate": (boolean, True),
        "DetectorId": (str, True),
        "Format": (str, True),
        "Location": (str, True),
        "Name": (str, False),
    }


class Master(AWSObject):
    resource_type = "AWS::GuardDuty::Master"

    props = {
        "DetectorId": (str, True),
        "InvitationId": (str, False),
        "MasterId": (str, True),
    }


class Member(AWSObject):
    resource_type = "AWS::GuardDuty::Member"

    props = {
        "DetectorId": (str, True),
        "Email": (str, True),
        "MemberId": (str, True),
        "Message": (str, False),
        "Status": (str, False),
        "DisableEmailNotification": (bool, False),
    }


class ThreatIntelSet(AWSObject):
    resource_type = "AWS::GuardDuty::ThreatIntelSet"

    props = {
        "Activate": (boolean, True),
        "DetectorId": (str, True),
        "Format": (str, True),
        "Location": (str, True),
        "Name": (str, False),
    }



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 31.0.0


from troposphere import Tags

from . import AWSObject, AWSProperty
from .validators import integer


class Agent(AWSObject):
    resource_type = "AWS::DataSync::Agent"

    props = {
        "ActivationKey": (str, True),
        "AgentName": (str, False),
        "SecurityGroupArns": ([str], False),
        "SubnetArns": ([str], False),
        "Tags": (Tags, False),
        "VpcEndpointId": (str, False),
    }


class Ec2Config(AWSProperty):
    props = {
        "SecurityGroupArns": ([str], True),
        "SubnetArn": (str, True),
    }


class LocationEFS(AWSObject):
    resource_type = "AWS::DataSync::LocationEFS"

    props = {
        "Ec2Config": (Ec2Config, True),
        "EfsFilesystemArn": (str, True),
        "Subdirectory": (str, False),
        "Tags": (Tags, False),
    }


class LocationFSxWindows(AWSObject):
    resource_type = "AWS::DataSync::LocationFSxWindows"

    props = {
        "Domain": (str, False),
        "FsxFilesystemArn": (str, True),
        "Password": (str, True),
        "SecurityGroupArns": ([str], True),
        "Subdirectory": (str, False),
        "Tags": (Tags, False),
        "User": (str, True),
    }


class MountOptions(AWSProperty):
    props = {
        "Version": (str, False),
    }


class OnPremConfig(AWSProperty):
    props = {
        "AgentArns": ([str], True),
    }


class LocationNFS(AWSObject):
    resource_type = "AWS::DataSync::LocationNFS"

    props = {
        "MountOptions": (MountOptions, False),
        "OnPremConfig": (OnPremConfig, True),
        "ServerHostname": (str, True),
        "Subdirectory": (str, True),
        "Tags": (Tags, False),
    }


class LocationObjectStorage(AWSObject):
    resource_type = "AWS::DataSync::LocationObjectStorage"

    props = {
        "AccessKey": (str, False),
        "AgentArns": ([str], True),
        "BucketName": (str, True),
        "SecretKey": (str, False),
        "ServerHostname": (str, True),
        "ServerPort": (integer, False),
        "ServerProtocol": (str, False),
        "Subdirectory": (str, False),
        "Tags": (Tags, False),
    }


class S3Config(AWSProperty):
    props = {
        "BucketAccessRoleArn": (str, True),
    }


class LocationS3(AWSObject):
    resource_type = "AWS::DataSync::LocationS3"

    props = {
        "S3BucketArn": (str, True),
        "S3Config": (S3Config, True),
        "S3StorageClass": (str, False),
        "Subdirectory": (str, False),
        "Tags": (Tags, False),
    }


class LocationSMB(AWSObject):
    resource_type = "AWS::DataSync::LocationSMB"

    props = {
        "AgentArns": ([str], True),
        "Domain": (str, False),
        "MountOptions": (MountOptions, False),
        "Password": (str, True),
        "ServerHostname": (str, True),
        "Subdirectory": (str, True),
        "Tags": (Tags, False),
        "User": (str, True),
    }


class FilterRule(AWSProperty):
    props = {
        "FilterType": (str, False),
        "Value": (str, False),
    }


class Options(AWSProperty):
    props = {
        "Atime": (str, False),
        "BytesPerSecond": (integer, False),
        "Gid": (str, False),
        "LogLevel": (str, False),
        "Mtime": (str, False),
        "OverwriteMode": (str, False),
        "PosixPermissions": (str, False),
        "PreserveDeletedFiles": (str, False),
        "PreserveDevices": (str, False),
        "TaskQueueing": (str, False),
        "TransferMode": (str, False),
        "Uid": (str, False),
        "VerifyMode": (str, False),
    }


class TaskSchedule(AWSProperty):
    props = {
        "ScheduleExpression": (str, True),
    }


class Task(AWSObject):
    resource_type = "AWS::DataSync::Task"

    props = {
        "CloudWatchLogGroupArn": (str, False),
        "DestinationLocationArn": (str, True),
        "Excludes": ([FilterRule], False),
        "Name": (str, False),
        "Options": (Options, False),
        "Schedule": (TaskSchedule, False),
        "SourceLocationArn": (str, True),
        "Tags": (Tags, False),
    }



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 39.3.0


from troposphere import Tags

from . import AWSObject
from .validators import boolean


class ResourceShare(AWSObject):
    resource_type = "AWS::RAM::ResourceShare"

    props = {
        "AllowExternalPrincipals": (boolean, False),
        "Name": (str, True),
        "PermissionArns": ([str], False),
        "Principals": ([str], False),
        "ResourceArns": ([str], False),
        "Tags": (Tags, False),
    }



# Copyright (c) 2012-2019, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 10.0.0


from . import AWSObject, AWSProperty
from .validators import (
    boolean,
    double,
    integer,
    integer_range,
    json_checker,
    positive_integer,
)


def validate_integration_type(integration_type):

    valid_integration_types = ["AWS", "AWS_PROXY", "HTTP", "HTTP_PROXY", "MOCK"]
    if integration_type not in valid_integration_types:
        raise ValueError("{} is not a valid IntegrationType".format(integration_type))
    return integration_type


def validate_authorizer_type(authorizer_type):

    valid_authorizer_types = ["REQUEST", "JWT"]
    if authorizer_type not in valid_authorizer_types:
        raise ValueError("{} is not a valid AuthorizerType".format(authorizer_type))
    return authorizer_type


def validate_logging_level(logging_level):

    valid_logging_levels = ["WARN", "INFO", "DEBUG"]
    if logging_level not in valid_logging_levels:
        raise ValueError("{} is not a valid LoggingLevel".format(logging_level))
    return logging_level


def validate_passthrough_behavior(passthrough_behavior):

    valid_passthrough_behaviors = ["WHEN_NO_MATCH", "WHEN_NO_TEMPLATES", "NEVER"]
    if passthrough_behavior not in valid_passthrough_behaviors:
        raise ValueError(
            "{} is not a valid PassthroughBehavior".format(passthrough_behavior)
        )
    return passthrough_behavior


def validate_content_handling_strategy(content_handling_strategy):

    valid_handling_strategy_values = ["CONVERT_TO_TEXT", "CONVERT_TO_BINARY"]
    if content_handling_strategy not in valid_handling_strategy_values:
        raise ValueError(
            "{} is not a valid ContentHandlingStrategy".format(
                content_handling_strategy
            )
        )
    return content_handling_strategy


def validate_authorizer_ttl(ttl_value):
    """Validate authorizer ttl timeout
    :param ttl_value: The TTL timeout in seconds
    :return: The provided TTL value if valid
    """
    ttl_value = int(positive_integer(ttl_value))
    if ttl_value > 3600:
        raise ValueError("The AuthorizerResultTtlInSeconds should be <= 3600")
    return ttl_value


class BodyS3Location(AWSProperty):
    props = {
        "Bucket": (str, False),
        "Etag": (str, False),
        "Key": (str, False),
        "Version": (str, False),
    }


class Cors(AWSProperty):
    props = {
        "AllowCredentials": (boolean, False),
        "AllowHeaders": ([str], False),
        "AllowMethods": ([str], False),
        "AllowOrigins": ([str], False),
        "ExposeHeaders": ([str], False),
        "MaxAge": (integer, False),
    }


class Api(AWSObject):
    resource_type = "AWS::ApiGatewayV2::Api"

    props = {
        "ApiKeySelectionExpression": (str, False),
        "BasePath": (str, False),
        "Body": (dict, False),
        "BodyS3Location": (BodyS3Location, False),
        "CorsConfiguration": (Cors, False),
        "CredentialsArn": (str, False),
        "Description": (str, False),
        "DisableExecuteApiEndpoint": (boolean, False),
        "DisableSchemaValidation": (boolean, False),
        "FailOnWarnings": (boolean, False),
        "Name": (str, False),
        "ProtocolType": (str, False),
        "RouteKey": (str, False),
        "RouteSelectionExpression": (str, False),
        "Tags": (dict, False),
        "Target": (str, False),
        "Version": (str, False),
    }


class ApiMapping(AWSObject):
    resource_type = "AWS::ApiGatewayV2::ApiMapping"

    props = {
        "ApiId": (str, True),
        "ApiMappingKey": (str, False),
        "DomainName": (str, True),
        "Stage": (str, True),
    }


class JWTConfiguration(AWSProperty):
    props = {
        "Audience": ([str], False),
        "Issuer": (str, False),
    }


class Authorizer(AWSObject):
    resource_type = "AWS::ApiGatewayV2::Authorizer"

    props = {
        "ApiId": (str, True),
        "AuthorizerCredentialsArn": (str, False),
        "AuthorizerPayloadFormatVersion": (str, False),
        "AuthorizerResultTtlInSeconds": (validate_authorizer_ttl, False),
        "AuthorizerType": (validate_authorizer_type, True),
        "AuthorizerUri": (str, False),
        "EnableSimpleResponses": (boolean, False),
        "IdentitySource": ([str], True),
        "IdentityValidationExpression": (str, False),
        "JwtConfiguration": (JWTConfiguration, False),
        "Name": (str, True),
    }


class Deployment(AWSObject):
    resource_type = "AWS::ApiGatewayV2::Deployment"

    props = {
        "ApiId": (str, True),
        "Description": (str, False),
        "StageName": (str, False),
    }


class DomainNameConfiguration(AWSProperty):
    props = {
        "CertificateArn": (str, False),
        "CertificateName": (str, False),
        "EndpointType": (str, False),
        "OwnershipVerificationCertificateArn": (str, False),
        "SecurityPolicy": (str, False),
    }


class MutualTlsAuthentication(AWSProperty):
    props = {
        "TruststoreUri": (str, False),
        "TruststoreVersion": (str, False),
    }


class DomainName(AWSObject):
    resource_type = "AWS::ApiGatewayV2::DomainName"

    props = {
        "DomainName": (str, True),
        "DomainNameConfigurations": ([DomainNameConfiguration], False),
        "MutualTlsAuthentication": (MutualTlsAuthentication, False),
        "Tags": (dict, False),
    }


class TlsConfig(AWSProperty):
    props = {
        "ServerNameToVerify": (str, False),
    }


class Integration(AWSObject):
    resource_type = "AWS::ApiGatewayV2::Integration"

    props = {
        "ApiId": (str, True),
        "ConnectionType": (str, False),
        "ConnectionId": (str, False),
        "ContentHandlingStrategy": (validate_content_handling_strategy, False),
        "CredentialsArn": (str, False),
        "Description": (str, False),
        "IntegrationMethod": (str, False),
        "IntegrationSubtype": (str, False),
        "IntegrationType": (validate_integration_type, True),
        "IntegrationUri": (str, False),
        "PassthroughBehavior": (validate_passthrough_behavior, False),
        "PayloadFormatVersion": (str, False),
        "RequestParameters": (dict, False),
        "RequestTemplates": (dict, False),
        "TemplateSelectionExpression": (str, False),
        "TimeoutInMillis": (integer_range(50, 29000), False),
        "TlsConfig": (TlsConfig, False),
    }


class IntegrationResponse(AWSObject):
    resource_type = "AWS::ApiGatewayV2::IntegrationResponse"

    props = {
        "ApiId": (str, True),
        "ContentHandlingStrategy": (validate_content_handling_strategy, False),
        "IntegrationId": (str, True),
        "IntegrationResponseKey": (str, True),
        "ResponseParameters": (dict, False),
        "ResponseTemplates": (dict, False),
        "TemplateSelectionExpression": (str, False),
    }


class Model(AWSObject):
    resource_type = "AWS::ApiGatewayV2::Model"

    props = {
        "ApiId": (str, True),
        "ContentType": (str, False),
        "Description": (str, False),
        "Name": (str, True),
        "Schema": ((str, dict), True),
    }

    def validate(self):
        name = "Schema"
        if name in self.properties:
            schema = self.properties.get(name)
            self.properties[name] = json_checker(schema)


class Route(AWSObject):
    resource_type = "AWS::ApiGatewayV2::Route"

    props = {
        "ApiId": (str, True),
        "ApiKeyRequired": (boolean, False),
        "AuthorizationScopes": ([str], False),
        "AuthorizationType": (str, False),
        "AuthorizerId": (str, False),
        "ModelSelectionExpression": (str, False),
        "OperationName": (str, False),
        "RequestModels": (dict, False),
        "RequestParameters": (dict, False),
        "RouteKey": (str, True),
        "RouteResponseSelectionExpression": (str, False),
        "Target": (str, False),
    }


class RouteResponse(AWSObject):
    resource_type = "AWS::ApiGatewayV2::RouteResponse"

    props = {
        "ApiId": (str, True),
        "ModelSelectionExpression": (str, False),
        "ResponseModels": (dict, False),
        "ResponseParameters": (dict, False),
        "RouteId": (str, True),
        "RouteResponseKey": (str, True),
    }


class AccessLogSettings(AWSProperty):
    props = {
        "DestinationArn": (str, False),
        "Format": (str, False),
    }


class RouteSettings(AWSProperty):
    props = {
        "DataTraceEnabled": (boolean, False),
        "DetailedMetricsEnabled": (boolean, False),
        "LoggingLevel": (validate_logging_level, False),
        "ThrottlingBurstLimit": (integer, False),
        "ThrottlingRateLimit": (double, False),
    }


class Stage(AWSObject):
    resource_type = "AWS::ApiGatewayV2::Stage"

    props = {
        "AccessLogSettings": (AccessLogSettings, False),
        "ApiId": (str, True),
        "AutoDeploy": (boolean, False),
        "ClientCertificateId": (str, False),
        "DefaultRouteSettings": (RouteSettings, False),
        "DeploymentId": (str, False),
        "Description": (str, False),
        "RouteSettings": (dict, False),
        "StageName": (str, True),
        "StageVariables": (dict, False),
        "Tags": (dict, False),
    }


class VpcLink(AWSObject):
    resource_type = "AWS::ApiGatewayV2::VpcLink"

    props = {
        "Name": (str, True),
        "SecurityGroupIds": ([str], False),
        "SubnetIds": ([str], True),
        "Tags": (dict, False),
    }



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 31.0.0


from . import AWSObject, AWSProperty
from .validators import double


class AnomalyMonitor(AWSObject):
    resource_type = "AWS::CE::AnomalyMonitor"

    props = {
        "MonitorDimension": (str, False),
        "MonitorName": (str, True),
        "MonitorSpecification": (str, False),
        "MonitorType": (str, True),
    }


class Subscriber(AWSProperty):
    props = {
        "Address": (str, True),
        "Status": (str, False),
        "Type": (str, True),
    }


class AnomalySubscription(AWSObject):
    resource_type = "AWS::CE::AnomalySubscription"

    props = {
        "Frequency": (str, True),
        "MonitorArnList": ([str], True),
        "Subscribers": ([Subscriber], True),
        "SubscriptionName": (str, True),
        "Threshold": (double, True),
    }


class CostCategory(AWSObject):
    resource_type = "AWS::CE::CostCategory"

    props = {
        "Name": (str, True),
        "RuleVersion": (str, True),
        "Rules": (str, True),
    }



# Copyright (c) 2012-2018, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from . import AWSObject, AWSProperty
from .validators import (
    boolean,
    double,
    integer,
    scalable_dimension_type,
    service_namespace_type,
    statistic_type,
)

VALID_PREDICTIVESCALINGMAXCAPACITYBEHAVIOR = (
    "SetForecastCapacityToMaxCapacity",
    "SetMaxCapacityToForecastCapacity",
    "SetMaxCapacityAboveForecastCapacity",
)
VALID_PREDICTIVESCALINGMODE = ("ForecastAndScale", "ForecastOnly")
VALID_SCALINGPOLICYUPDATEBEHAVIOR = ("KeepExternalPolicies", "ReplaceExternalPolicies")


def validate_predictivescalingmaxcapacitybehavior(predictivescalingmaxcapacitybehavior):
    """Validate PredictiveScalingMaxCapacityBehavior for ScalingInstruction"""  # noqa

    if (
        predictivescalingmaxcapacitybehavior
        not in VALID_PREDICTIVESCALINGMAXCAPACITYBEHAVIOR
    ):  # noqa
        raise ValueError(
            "ScalingInstruction PredictiveScalingMaxCapacityBehavior must be one of: %s"
            % ", ".join(VALID_PREDICTIVESCALINGMAXCAPACITYBEHAVIOR)  # noqa
        )
    return predictivescalingmaxcapacitybehavior


def validate_predictivescalingmode(predictivescalingmode):
    """Validate PredictiveScalingMode for ScalingInstruction"""

    if predictivescalingmode not in VALID_PREDICTIVESCALINGMODE:
        raise ValueError(
            "ScalingInstruction PredictiveScalingMode must be one of: %s"
            % ", ".join(VALID_PREDICTIVESCALINGMODE)  # noqa
        )
    return predictivescalingmode


def validate_scalingpolicyupdatebehavior(scalingpolicyupdatebehavior):
    """Validate ScalingPolicyUpdateBehavior for ScalingInstruction"""

    if scalingpolicyupdatebehavior not in VALID_SCALINGPOLICYUPDATEBEHAVIOR:
        raise ValueError(
            "ScalingInstruction ScalingPolicyUpdateBehavior must be one of: %s"
            % ", ".join(VALID_SCALINGPOLICYUPDATEBEHAVIOR)  # noqa
        )
    return scalingpolicyupdatebehavior


class TagFilter(AWSProperty):
    props = {"Values": ([str], False), "Key": (str, True)}


class ApplicationSource(AWSProperty):
    props = {"CloudFormationStackARN": (str, False), "TagFilters": ([TagFilter], False)}


class PredefinedScalingMetricSpecification(AWSProperty):
    props = {"ResourceLabel": (str, False), "PredefinedScalingMetricType": (str, True)}


class MetricDimension(AWSProperty):
    props = {"Value": (str, True), "Name": (str, True)}


class CustomizedScalingMetricSpecification(AWSProperty):
    props = {
        "MetricName": (str, True),
        "Statistic": (statistic_type, True),
        "Dimensions": ([MetricDimension], False),
        "Unit": (str, False),
        "Namespace": (str, True),
    }


class TargetTrackingConfiguration(AWSProperty):
    props = {
        "ScaleOutCooldown": (integer, False),
        "TargetValue": (double, True),
        "PredefinedScalingMetricSpecification": (
            PredefinedScalingMetricSpecification,
            False,
        ),
        "DisableScaleIn": (boolean, False),
        "ScaleInCooldown": (integer, False),
        "EstimatedInstanceWarmup": (integer, False),
        "CustomizedScalingMetricSpecification": (
            CustomizedScalingMetricSpecification,
            False,
        ),
    }


class CustomizedLoadMetricSpecification(AWSObject):
    props = {
        "Dimensions": ([MetricDimension], False),
        "MetricName": (str, True),
        "Namespace": (str, True),
        "Statistic": (str, True),
        "Unit": (str, False),
    }


class PredefinedLoadMetricSpecification(AWSProperty):
    props = {
        "PredefinedLoadMetricType": (str, True),
        "ResourceLabel": (str, False),
    }


class ScalingInstruction(AWSProperty):
    props = {
        "CustomizedLoadMetricSpecification": (
            CustomizedLoadMetricSpecification,
            False,
        ),  # NOQA
        "DisableDynamicScaling": (boolean, False),
        "MaxCapacity": (integer, True),
        "MinCapacity": (integer, True),
        "PredefinedLoadMetricSpecification": (
            PredefinedLoadMetricSpecification,
            False,
        ),  # NOQA
        "PredictiveScalingMaxCapacityBehavior": (
            validate_predictivescalingmaxcapacitybehavior,
            False,
        ),  # NOQA
        "PredictiveScalingMaxCapacityBuffer": (integer, False),
        "PredictiveScalingMode": (validate_predictivescalingmode, False),
        "ResourceId": (str, True),
        "ScalableDimension": (scalable_dimension_type, True),
        "ScalingPolicyUpdateBehavior": (
            validate_scalingpolicyupdatebehavior,
            False,
        ),  # NOQA
        "ScheduledActionBufferTime": (integer, False),
        "ServiceNamespace": (service_namespace_type, True),
        "TargetTrackingConfigurations": ([TargetTrackingConfiguration], True),
    }


class ScalingPlan(AWSObject):
    resource_type = "AWS::AutoScalingPlans::ScalingPlan"

    props = {
        "ApplicationSource": (ApplicationSource, True),
        "ScalingInstructions": ([ScalingInstruction], True),
    }



# Copyright (c) 2012-2019, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 8.1.0


from . import AWSObject, AWSProperty
from .validators import integer


class AccelerationSettings(AWSProperty):
    props = {
        "Mode": (str, True),
    }


class JobTemplate(AWSObject):
    resource_type = "AWS::MediaConvert::JobTemplate"

    props = {
        "AccelerationSettings": (AccelerationSettings, False),
        "Category": (str, False),
        "Description": (str, False),
        "Name": (str, False),
        "Priority": (integer, False),
        "Queue": (str, False),
        "SettingsJson": (dict, True),
        "StatusUpdateInterval": (str, False),
        "Tags": (dict, False),
    }


class Preset(AWSObject):
    resource_type = "AWS::MediaConvert::Preset"

    props = {
        "Category": (str, False),
        "Description": (str, False),
        "Name": (str, False),
        "SettingsJson": (dict, True),
        "Tags": (dict, False),
    }


class Queue(AWSObject):
    resource_type = "AWS::MediaConvert::Queue"

    props = {
        "Description": (str, False),
        "Name": (str, False),
        "PricingPlan": (str, False),
        "Status": (str, False),
        "Tags": (dict, False),
    }



# Converted from CodePipeline example located at:
# http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codepipeline-pipeline.html # noqa

from troposphere import Parameter, Ref, Template
from troposphere.codepipeline import (
    Actions,
    ActionTypeId,
    ArtifactStore,
    DisableInboundStageTransitions,
    InputArtifacts,
    OutputArtifacts,
    Pipeline,
    Stages,
)

t = Template()


CodePipelineServiceRole = t.add_parameter(
    Parameter(
        "CodePipelineServiceRole",
        Description="The CodePipelineServiceRole ARN to use",
        Type="String",
    )
)

ArtifactStoreS3Location = t.add_parameter(
    Parameter(
        "ArtifactStoreS3Location",
        Description="This should be an S3 bucket resource or bucket name",
        Type="String",
    )
)

pipeline = t.add_resource(
    Pipeline(
        "AppPipeline",
        RoleArn=Ref(CodePipelineServiceRole),
        Stages=[
            Stages(
                Name="Source",
                Actions=[
                    Actions(
                        Name="SourceAction",
                        ActionTypeId=ActionTypeId(
                            Category="Source", Owner="AWS", Version="1", Provider="S3"
                        ),
                        OutputArtifacts=[OutputArtifacts(Name="SourceOutput")],
                        Configuration={
                            "S3Bucket": {"Ref": "SourceS3Bucket"},
                            "S3ObjectKey": {"Ref": "SourceS3ObjectKey"},
                        },
                        RunOrder="1",
                    )
                ],
            ),
            Stages(
                Name="Beta",
                Actions=[
                    Actions(
                        Name="BetaAction",
                        InputArtifacts=[InputArtifacts(Name="SourceOutput")],
                        ActionTypeId=ActionTypeId(
                            Category="Deploy",
                            Owner="AWS",
                            Version="1",
                            Provider="CodeDeploy",
                        ),
                        Configuration={
                            "ApplicationName": {"Ref": "ApplicationName"},
                            "DeploymentGroupName": {"Ref": "DeploymentGroupName"},
                        },
                        RunOrder="1",
                    )
                ],
            ),
            Stages(
                Name="Release",
                Actions=[
                    Actions(
                        Name="ReleaseAction",
                        InputArtifacts=[InputArtifacts(Name="SourceOutput")],
                        ActionTypeId=ActionTypeId(
                            Category="Deploy",
                            Owner="AWS",
                            Version="1",
                            Provider="CodeDeploy",
                        ),
                        Configuration={
                            "ApplicationName": {"Ref": "ApplicationName"},
                            "DeploymentGroupName": {"Ref": "DeploymentGroupName"},
                        },
                        RunOrder="1",
                    )
                ],
            ),
        ],
        ArtifactStore=ArtifactStore(Type="S3", Location=Ref(ArtifactStoreS3Location)),
        DisableInboundStageTransitions=[
            DisableInboundStageTransitions(
                StageName="Release",
                Reason="Disabling the transition until "
                "integration tests are completed",
            )
        ],
    )
)


print(t.to_json())



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 31.0.0


from . import AWSObject, AWSProperty
from .validators import boolean, double, integer


class ADMChannel(AWSObject):
    resource_type = "AWS::Pinpoint::ADMChannel"

    props = {
        "ApplicationId": (str, True),
        "ClientId": (str, True),
        "ClientSecret": (str, True),
        "Enabled": (boolean, False),
    }


class APNSChannel(AWSObject):
    resource_type = "AWS::Pinpoint::APNSChannel"

    props = {
        "ApplicationId": (str, True),
        "BundleId": (str, False),
        "Certificate": (str, False),
        "DefaultAuthenticationMethod": (str, False),
        "Enabled": (boolean, False),
        "PrivateKey": (str, False),
        "TeamId": (str, False),
        "TokenKey": (str, False),
        "TokenKeyId": (str, False),
    }


class APNSSandboxChannel(AWSObject):
    resource_type = "AWS::Pinpoint::APNSSandboxChannel"

    props = {
        "ApplicationId": (str, True),
        "BundleId": (str, False),
        "Certificate": (str, False),
        "DefaultAuthenticationMethod": (str, False),
        "Enabled": (boolean, False),
        "PrivateKey": (str, False),
        "TeamId": (str, False),
        "TokenKey": (str, False),
        "TokenKeyId": (str, False),
    }


class APNSVoipChannel(AWSObject):
    resource_type = "AWS::Pinpoint::APNSVoipChannel"

    props = {
        "ApplicationId": (str, True),
        "BundleId": (str, False),
        "Certificate": (str, False),
        "DefaultAuthenticationMethod": (str, False),
        "Enabled": (boolean, False),
        "PrivateKey": (str, False),
        "TeamId": (str, False),
        "TokenKey": (str, False),
        "TokenKeyId": (str, False),
    }


class APNSVoipSandboxChannel(AWSObject):
    resource_type = "AWS::Pinpoint::APNSVoipSandboxChannel"

    props = {
        "ApplicationId": (str, True),
        "BundleId": (str, False),
        "Certificate": (str, False),
        "DefaultAuthenticationMethod": (str, False),
        "Enabled": (boolean, False),
        "PrivateKey": (str, False),
        "TeamId": (str, False),
        "TokenKey": (str, False),
        "TokenKeyId": (str, False),
    }


class App(AWSObject):
    resource_type = "AWS::Pinpoint::App"

    props = {
        "Name": (str, True),
        "Tags": (dict, False),
    }


class CampaignHook(AWSProperty):
    props = {
        "LambdaFunctionName": (str, False),
        "Mode": (str, False),
        "WebUrl": (str, False),
    }


class Limits(AWSProperty):
    props = {
        "Daily": (integer, False),
        "MaximumDuration": (integer, False),
        "MessagesPerSecond": (integer, False),
        "Total": (integer, False),
    }


class QuietTime(AWSProperty):
    props = {
        "End": (str, True),
        "Start": (str, True),
    }


class ApplicationSettings(AWSObject):
    resource_type = "AWS::Pinpoint::ApplicationSettings"

    props = {
        "ApplicationId": (str, True),
        "CampaignHook": (CampaignHook, False),
        "CloudWatchMetricsEnabled": (boolean, False),
        "Limits": (Limits, False),
        "QuietTime": (QuietTime, False),
    }


class BaiduChannel(AWSObject):
    resource_type = "AWS::Pinpoint::BaiduChannel"

    props = {
        "ApiKey": (str, True),
        "ApplicationId": (str, True),
        "Enabled": (boolean, False),
        "SecretKey": (str, True),
    }


class CampaignEmailMessage(AWSProperty):
    props = {
        "Body": (str, False),
        "FromAddress": (str, False),
        "HtmlBody": (str, False),
        "Title": (str, False),
    }


class CampaignSmsMessage(AWSProperty):
    props = {
        "Body": (str, False),
        "EntityId": (str, False),
        "MessageType": (str, False),
        "OriginationNumber": (str, False),
        "SenderId": (str, False),
        "TemplateId": (str, False),
    }


class Message(AWSProperty):
    props = {
        "Action": (str, False),
        "Body": (str, False),
        "ImageIconUrl": (str, False),
        "ImageSmallIconUrl": (str, False),
        "ImageUrl": (str, False),
        "JsonBody": (str, False),
        "MediaUrl": (str, False),
        "RawContent": (str, False),
        "SilentPush": (boolean, False),
        "TimeToLive": (integer, False),
        "Title": (str, False),
        "Url": (str, False),
    }


class MessageConfiguration(AWSProperty):
    props = {
        "ADMMessage": (Message, False),
        "APNSMessage": (Message, False),
        "BaiduMessage": (Message, False),
        "DefaultMessage": (Message, False),
        "EmailMessage": (CampaignEmailMessage, False),
        "GCMMessage": (Message, False),
        "SMSMessage": (CampaignSmsMessage, False),
    }


class SetDimension(AWSProperty):
    props = {
        "DimensionType": (str, False),
        "Values": ([str], False),
    }


class EventDimensions(AWSProperty):
    props = {
        "Attributes": (dict, False),
        "EventType": (SetDimension, False),
        "Metrics": (dict, False),
    }


class CampaignEventFilter(AWSProperty):
    props = {
        "Dimensions": (EventDimensions, False),
        "FilterType": (str, False),
    }


class Schedule(AWSProperty):
    props = {
        "EndTime": (str, False),
        "EventFilter": (CampaignEventFilter, False),
        "Frequency": (str, False),
        "IsLocalTime": (boolean, False),
        "QuietTime": (QuietTime, False),
        "StartTime": (str, False),
        "TimeZone": (str, False),
    }


class WriteTreatmentResource(AWSProperty):
    props = {
        "MessageConfiguration": (MessageConfiguration, False),
        "Schedule": (Schedule, False),
        "SizePercent": (integer, False),
        "TreatmentDescription": (str, False),
        "TreatmentName": (str, False),
    }


class Campaign(AWSObject):
    resource_type = "AWS::Pinpoint::Campaign"

    props = {
        "AdditionalTreatments": ([WriteTreatmentResource], False),
        "ApplicationId": (str, True),
        "CampaignHook": (CampaignHook, False),
        "Description": (str, False),
        "HoldoutPercent": (integer, False),
        "IsPaused": (boolean, False),
        "Limits": (Limits, False),
        "MessageConfiguration": (MessageConfiguration, True),
        "Name": (str, True),
        "Schedule": (Schedule, True),
        "SegmentId": (str, True),
        "SegmentVersion": (integer, False),
        "Tags": (dict, False),
        "TreatmentDescription": (str, False),
        "TreatmentName": (str, False),
    }


class EmailChannel(AWSObject):
    resource_type = "AWS::Pinpoint::EmailChannel"

    props = {
        "ApplicationId": (str, True),
        "ConfigurationSet": (str, False),
        "Enabled": (boolean, False),
        "FromAddress": (str, True),
        "Identity": (str, True),
        "RoleArn": (str, False),
    }


class EmailTemplate(AWSObject):
    resource_type = "AWS::Pinpoint::EmailTemplate"

    props = {
        "DefaultSubstitutions": (str, False),
        "HtmlPart": (str, False),
        "Subject": (str, True),
        "Tags": (dict, False),
        "TemplateDescription": (str, False),
        "TemplateName": (str, True),
        "TextPart": (str, False),
    }


class EventStream(AWSObject):
    resource_type = "AWS::Pinpoint::EventStream"

    props = {
        "ApplicationId": (str, True),
        "DestinationStreamArn": (str, True),
        "RoleArn": (str, True),
    }


class GCMChannel(AWSObject):
    resource_type = "AWS::Pinpoint::GCMChannel"

    props = {
        "ApiKey": (str, True),
        "ApplicationId": (str, True),
        "Enabled": (boolean, False),
    }


class APNSPushNotificationTemplate(AWSProperty):
    props = {
        "Action": (str, False),
        "Body": (str, False),
        "MediaUrl": (str, False),
        "Sound": (str, False),
        "Title": (str, False),
        "Url": (str, False),
    }


class AndroidPushNotificationTemplate(AWSProperty):
    props = {
        "Action": (str, False),
        "Body": (str, False),
        "ImageIconUrl": (str, False),
        "ImageUrl": (str, False),
        "SmallImageIconUrl": (str, False),
        "Sound": (str, False),
        "Title": (str, False),
        "Url": (str, False),
    }


class DefaultPushNotificationTemplate(AWSProperty):
    props = {
        "Action": (str, False),
        "Body": (str, False),
        "Sound": (str, False),
        "Title": (str, False),
        "Url": (str, False),
    }


class PushTemplate(AWSObject):
    resource_type = "AWS::Pinpoint::PushTemplate"

    props = {
        "ADM": (AndroidPushNotificationTemplate, False),
        "APNS": (APNSPushNotificationTemplate, False),
        "Baidu": (AndroidPushNotificationTemplate, False),
        "Default": (DefaultPushNotificationTemplate, False),
        "DefaultSubstitutions": (str, False),
        "GCM": (AndroidPushNotificationTemplate, False),
        "Tags": (dict, False),
        "TemplateDescription": (str, False),
        "TemplateName": (str, True),
    }


class SMSChannel(AWSObject):
    resource_type = "AWS::Pinpoint::SMSChannel"

    props = {
        "ApplicationId": (str, True),
        "Enabled": (boolean, False),
        "SenderId": (str, False),
        "ShortCode": (str, False),
    }


class Recency(AWSProperty):
    props = {
        "Duration": (str, True),
        "RecencyType": (str, True),
    }


class Behavior(AWSProperty):
    props = {
        "Recency": (Recency, False),
    }


class Demographic(AWSProperty):
    props = {
        "AppVersion": (SetDimension, False),
        "Channel": (SetDimension, False),
        "DeviceType": (SetDimension, False),
        "Make": (SetDimension, False),
        "Model": (SetDimension, False),
        "Platform": (SetDimension, False),
    }


class Coordinates(AWSProperty):
    props = {
        "Latitude": (double, True),
        "Longitude": (double, True),
    }


class GPSPoint(AWSProperty):
    props = {
        "Coordinates": (Coordinates, True),
        "RangeInKilometers": (double, True),
    }


class Location(AWSProperty):
    props = {
        "Country": (SetDimension, False),
        "GPSPoint": (GPSPoint, False),
    }


class SegmentDimensions(AWSProperty):
    props = {
        "Attributes": (dict, False),
        "Behavior": (Behavior, False),
        "Demographic": (Demographic, False),
        "Location": (Location, False),
        "Metrics": (dict, False),
        "UserAttributes": (dict, False),
    }


class SourceSegments(AWSProperty):
    props = {
        "Id": (str, True),
        "Version": (integer, False),
    }


class Groups(AWSProperty):
    props = {
        "Dimensions": ([SegmentDimensions], False),
        "SourceSegments": ([SourceSegments], False),
        "SourceType": (str, False),
        "Type": (str, False),
    }


class SegmentGroups(AWSProperty):
    props = {
        "Groups": ([Groups], False),
        "Include": (str, False),
    }


class Segment(AWSObject):
    resource_type = "AWS::Pinpoint::Segment"

    props = {
        "ApplicationId": (str, True),
        "Dimensions": (SegmentDimensions, False),
        "Name": (str, True),
        "SegmentGroups": (SegmentGroups, False),
        "Tags": (dict, False),
    }


class SmsTemplate(AWSObject):
    resource_type = "AWS::Pinpoint::SmsTemplate"

    props = {
        "Body": (str, True),
        "DefaultSubstitutions": (str, False),
        "Tags": (dict, False),
        "TemplateDescription": (str, False),
        "TemplateName": (str, True),
    }


class VoiceChannel(AWSObject):
    resource_type = "AWS::Pinpoint::VoiceChannel"

    props = {
        "ApplicationId": (str, True),
        "Enabled": (boolean, False),
    }



from troposphere import FindInMap, GetAtt, Join, Output, Parameter, Ref, Template
from troposphere.awslambda import MAXIMUM_MEMORY, MINIMUM_MEMORY, Code, Function
from troposphere.cloudformation import CustomResource
from troposphere.constants import NUMBER
from troposphere.ec2 import Instance, SecurityGroup
from troposphere.iam import Policy, Role

t = Template()

t.set_version("2010-09-09")

ExistingVPC = t.add_parameter(
    Parameter(
        "ExistingVPC",
        Type="AWS::EC2::VPC::Id",
        Description=(
            "The VPC ID that includes the security groups in the "
            "ExistingSecurityGroups parameter."
        ),
    )
)

InstanceType = t.add_parameter(
    Parameter(
        "InstanceType",
        Default="t2.micro",
        Type="String",
        AllowedValues=["t2.micro", "m1.small"],
    )
)

ExistingSecurityGroups = t.add_parameter(
    Parameter(
        "ExistingSecurityGroups",
        Type="List<AWS::EC2::SecurityGroup::Id>",
    )
)

MemorySize = t.add_parameter(
    Parameter(
        "LambdaMemorySize",
        Type=NUMBER,
        Description="Amount of memory to allocate to the Lambda Function",
        Default="128",
        MinValue=MINIMUM_MEMORY,
        MaxValue=MAXIMUM_MEMORY,
    )
)

Timeout = t.add_parameter(
    Parameter(
        "LambdaTimeout",
        Type=NUMBER,
        Description="Timeout in seconds for the Lambda function",
        Default="60",
    )
)

t.add_mapping(
    "AWSInstanceType2Arch",
    {"m1.small": {"Arch": "PV64"}, "t2.micro": {"Arch": "HVM64"}},
)

t.add_mapping(
    "AWSRegionArch2AMI",
    {
        "ap-northeast-1": {"HVM64": "ami-cbf90ecb", "PV64": "ami-27f90e27"},
        "ap-southeast-1": {"HVM64": "ami-68d8e93a", "PV64": "ami-acd9e8fe"},
        "ap-southeast-2": {"HVM64": "ami-fd9cecc7", "PV64": "ami-ff9cecc5"},
        "cn-north-1": {"HVM64": "ami-f239abcb", "PV64": "ami-fa39abc3"},
        "eu-central-1": {"HVM64": "ami-a8221fb5", "PV64": "ami-ac221fb1"},
        "eu-west-1": {"HVM64": "ami-a10897d6", "PV64": "ami-bf0897c8"},
        "sa-east-1": {"HVM64": "ami-b52890a8", "PV64": "ami-bb2890a6"},
        "us-east-1": {"HVM64": "ami-1ecae776", "PV64": "ami-1ccae774"},
        "us-west-1": {"HVM64": "ami-d114f295", "PV64": "ami-d514f291"},
        "us-west-2": {"HVM64": "ami-e7527ed7", "PV64": "ami-ff527ecf"},
    },
)

code = [
    "var response = require('cfn-response');",
    "exports.handler = function(event, context) {",
    "   var responseData = {Value: event.ResourceProperties.List};",
    "   responseData.Value.push(event.ResourceProperties.AppendedItem);",
    "   response.send(event, context, response.SUCCESS, responseData);",
    "};",
]

AppendItemToListFunction = t.add_resource(
    Function(
        "AppendItemToListFunction",
        Code=Code(ZipFile=Join("", code)),
        Handler="index.handler",
        Role=GetAtt("LambdaExecutionRole", "Arn"),
        Runtime="nodejs",
        MemorySize=Ref(MemorySize),
        Timeout=Ref(Timeout),
    )
)

LambdaExecutionRole = t.add_resource(
    Role(
        "LambdaExecutionRole",
        Path="/",
        Policies=[
            Policy(
                PolicyName="root",
                PolicyDocument={
                    "Version": "2012-10-17",
                    "Statement": [
                        {
                            "Action": ["logs:*"],
                            "Resource": "arn:aws:logs:*:*:*",
                            "Effect": "Allow",
                        }
                    ],
                },
            )
        ],
        AssumeRolePolicyDocument={
            "Version": "2012-10-17",
            "Statement": [
                {
                    "Action": ["sts:AssumeRole"],
                    "Effect": "Allow",
                    "Principal": {"Service": ["lambda.amazonaws.com"]},
                }
            ],
        },
    )
)

MyEC2Instance = t.add_resource(
    Instance(
        "MyEC2Instance",
        SecurityGroupIds=GetAtt("AllSecurityGroups", "Value"),
        InstanceType=Ref(InstanceType),
        ImageId=FindInMap(
            "AWSRegionArch2AMI",
            Ref("AWS::Region"),
            FindInMap("AWSInstanceType2Arch", Ref(InstanceType), "Arch"),
        ),
    )
)

AllSecurityGroups = t.add_resource(
    CustomResource(
        "AllSecurityGroups",
        List=Ref(ExistingSecurityGroups),
        AppendedItem=Ref("SecurityGroup"),
        ServiceToken=GetAtt(AppendItemToListFunction, "Arn"),
    )
)

SecurityGroup = t.add_resource(
    SecurityGroup(
        "SecurityGroup",
        SecurityGroupIngress=[
            {
                "ToPort": "80",
                "IpProtocol": "tcp",
                "CidrIp": "0.0.0.0/0",
                "FromPort": "80",
            }
        ],
        VpcId=Ref(ExistingVPC),
        GroupDescription="Allow HTTP traffic to the host",
        SecurityGroupEgress=[
            {
                "ToPort": "80",
                "IpProtocol": "tcp",
                "CidrIp": "0.0.0.0/0",
                "FromPort": "80",
            }
        ],
    )
)

AllSecurityGroups = t.add_output(
    Output(
        "AllSecurityGroups",
        Description="Security Groups that are associated with the EC2 instance",
        Value=Join(", ", GetAtt(AllSecurityGroups, "Value")),
    )
)

print(t.to_json())



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 39.3.0


from troposphere import Tags

from . import AWSObject, AWSProperty


class PhoneNumberQuickConnectConfig(AWSProperty):
    props = {
        "PhoneNumber": (str, True),
    }


class QueueQuickConnectConfig(AWSProperty):
    props = {
        "ContactFlowArn": (str, True),
        "QueueArn": (str, True),
    }


class UserQuickConnectConfig(AWSProperty):
    props = {
        "ContactFlowArn": (str, True),
        "UserArn": (str, True),
    }


class QuickConnectConfig(AWSProperty):
    props = {
        "PhoneConfig": (PhoneNumberQuickConnectConfig, False),
        "QueueConfig": (QueueQuickConnectConfig, False),
        "QuickConnectType": (str, True),
        "UserConfig": (UserQuickConnectConfig, False),
    }


class QuickConnect(AWSObject):
    resource_type = "AWS::Connect::QuickConnect"

    props = {
        "Description": (str, False),
        "InstanceArn": (str, True),
        "Name": (str, True),
        "QuickConnectConfig": (QuickConnectConfig, True),
        "Tags": (Tags, False),
    }



#
# Regions
#

AF_SOUTH_1 = "af-south-1"
AP_EAST_1 = "ap-east-1"
AP_NORTHEAST_1 = "ap-northeast-1"
AP_NORTHEAST_2 = "ap-northeast-2"
AP_NORTHEAST_3 = "ap-northeast-3"
AP_SOUTHEAST_1 = "ap-southeast-1"
AP_SOUTHEAST_2 = "ap-southeast-2"
AP_SOUTH_1 = "ap-south-1"
CA_CENTRAL_1 = "ca-central-1"
CN_NORTH_1 = "cn-north-1"
CN_NORTHWEST_1 = "cn-northwest-1"
EU_WEST_1 = "eu-west-1"
EU_WEST_2 = "eu-west-2"
EU_WEST_3 = "eu-west-3"
EU_CENTRAL_1 = "eu-central-1"
EU_NORTH_1 = "eu-north-1"
EU_SOUTH_1 = "eu-south-1"
ME_SOUTH_1 = "me-south-1"
SA_EAST_1 = "sa-east-1"
US_EAST_1 = "us-east-1"
US_EAST_2 = "us-east-2"
US_GOV_EAST_1 = "us-gov-east-1"
US_GOV_WEST_1 = "us-gov-west-1"
US_WEST_1 = "us-west-1"
US_WEST_2 = "us-west-2"

#
# Availability Zones
#

AF_SOUTH_1A = "af-south-1a"
AF_SOUTH_1B = "af-south-1b"
AF_SOUTH_1C = "af-south-1c"

AP_EAST_1A = "ap-east-1a"
AP_EAST_1B = "ap-east-1b"
AP_EAST_1C = "ap-east-1c"

AP_NORTHEAST_1A = "ap-northeast-1a"
AP_NORTHEAST_1B = "ap-northeast-1b"
AP_NORTHEAST_1C = "ap-northeast-1c"
AP_NORTHEAST_1D = "ap-northeast-1d"

AP_NORTHEAST_2A = "ap-northeast-2a"
AP_NORTHEAST_2B = "ap-northeast-2b"
AP_NORTHEAST_2C = "ap-northeast-2c"
AP_NORTHEAST_2D = "ap-northeast-2d"

AP_NORTHEAST_3A = "ap-northeast-3a"

AP_SOUTHEAST_1A = "ap-southeast-1a"
AP_SOUTHEAST_1B = "ap-southeast-1b"
AP_SOUTHEAST_1C = "ap-southeast-1c"

AP_SOUTHEAST_2A = "ap-southeast-2a"
AP_SOUTHEAST_2B = "ap-southeast-2b"
AP_SOUTHEAST_2C = "ap-southeast-2c"

AP_SOUTH_1A = "ap-south-1a"
AP_SOUTH_1B = "ap-south-1b"
AP_SOUTH_1C = "ap-south-1c"

CA_CENTRAL_1A = "ca-central-1a"
CA_CENTRAL_1B = "ca-central-1b"
CA_CENTRAL_1D = "ca-central-1d"

CN_NORTH_1A = "cn-north-1a"
CN_NORTH_1B = "cn-north-1b"

CN_NORTHWEST_1A = "cn-northwest-1a"
CN_NORTHWEST_1B = "cn-northwest-1b"
CN_NORTHWEST_1C = "cn-northwest-1c"

EU_WEST_1A = "eu-west-1a"
EU_WEST_1B = "eu-west-1b"
EU_WEST_1C = "eu-west-1c"

EU_WEST_2A = "eu-west-2a"
EU_WEST_2B = "eu-west-2b"
EU_WEST_2C = "eu-west-2c"

EU_WEST_3A = "eu-west-3a"
EU_WEST_3B = "eu-west-3b"
EU_WEST_3C = "eu-west-3c"

EU_CENTRAL_1A = "eu-central-1a"
EU_CENTRAL_1B = "eu-central-1b"
EU_CENTRAL_1C = "eu-central-1c"

EU_NORTH_1A = "eu-north-1a"
EU_NORTH_1B = "eu-north-1b"
EU_NORTH_1C = "eu-north-1c"

EU_SOUTH_1A = "eu-south-1a"
EU_SOUTH_1B = "eu-south-1b"
EU_SOUTH_1C = "eu-south-1c"

ME_SOUTH_1A = "me-south-1a"
ME_SOUTH_1B = "me-south-1b"
ME_SOUTH_1C = "me-south-1c"

SA_EAST_1A = "sa-east-1a"
SA_EAST_1B = "sa-east-1b"
SA_EAST_1C = "sa-east-1c"

US_EAST_1A = "us-east-1a"
US_EAST_1B = "us-east-1b"
US_EAST_1C = "us-east-1c"
US_EAST_1D = "us-east-1d"
US_EAST_1E = "us-east-1e"
US_EAST_1F = "us-east-1f"

US_EAST_2A = "us-east-2a"
US_EAST_2B = "us-east-2b"
US_EAST_2C = "us-east-2c"

US_WEST_1A = "us-west-1a"
US_WEST_1B = "us-west-1b"
US_WEST_1C = "us-west-1c"

US_GOV_EAST_1A = "us-gov-east-1a"
US_GOV_EAST_1B = "us-gov-east-1b"
US_GOV_EAST_1C = "us-gov-east-1c"

US_GOV_WEST_1A = "us-gov-west-1a"
US_GOV_WEST_1B = "us-gov-west-1b"
US_GOV_WEST_1C = "us-gov-west-1c"

US_WEST_2A = "us-west-2a"
US_WEST_2B = "us-west-2b"
US_WEST_2C = "us-west-2c"
US_WEST_2D = "us-west-2d"

#
# Networking
#

QUAD_ZERO = "0.0.0.0/0"
VPC_CIDR_16 = "10.0.0.0/16"

SSH_PORT = 22
MONGODB_PORT = 27017
NTP_PORT = 123
SMTP_PORT_25 = 25
SMTP_PORT_587 = 587
HTTP_PORT = 80
HTTPS_PORT = 443
REDIS_PORT = 6379
MEMCACHED_PORT = 11211
POSTGRESQL_PORT = 5432

TCP_PROTOCOL = 6
UDP_PROTOCOL = 17
ICMP_PROTOCOL = 1
ALL_PROTOCOL = -1

#
# EC2 instance types
#

T2_NANO = "t2.nano"
T2_MICRO = "t2.micro"
T2_SMALL = "t2.small"
T2_MEDIUM = "t2.medium"
T2_LARGE = "t2.large"
T2_XLARGE = "t2.xlarge"
T2_2XLARGE = "t2.2xlarge"

T3_NANO = "t3.nano"
T3_MICRO = "t3.micro"
T3_SMALL = "t3.small"
T3_MEDIUM = "t3.medium"
T3_LARGE = "t3.large"
T3_XLARGE = "t3.xlarge"
T3_2XLARGE = "t3.2xlarge"

T3A_NANO = "t3a.nano"
T3A_MICRO = "t3a.micro"
T3A_SMALL = "t3a.small"
T3A_MEDIUM = "t3a.medium"
T3A_LARGE = "t3a.large"
T3A_XLARGE = "t3a.xlarge"
T3A_2XLARGE = "t3a.2xlarge"

T4G_NANO = "t4g.nano"
T4G_MICRO = "t4g.micro"
T4G_SMALL = "t4g.small"
T4G_MEDIUM = "t4g.medium"
T4G_LARGE = "t4g.large"
T4G_XLARGE = "t4g.xlarge"
T4G_2XLARGE = "t4g.2xlarge"

M6G_MEDIUM = "m6g.medium"
M6G_LARGE = "m6g.large"
M6G_XLARGE = "m6g.xlarge"
M6G_2XLARGE = "m6g.2xlarge"
M6G_4XLARGE = "m6g.4xlarge"
M6G_8XLARGE = "m6g.8xlarge"
M6G_12XLARGE = "m6g.12xlarge"
M6G_16XLARGE = "m6g.16xlarge"
M6G_METAL = "m6g.metal"

M6GD_MEDIUM = "m6gd.medium"
M6GD_LARGE = "m6gd.large"
M6GD_XLARGE = "m6gd.xlarge"
M6GD_2XLARGE = "m6gd.2xlarge"
M6GD_4XLARGE = "m6gd.4xlarge"
M6GD_8XLARGE = "m6gd.8xlarge"
M6GD_12XLARGE = "m6gd.12xlarge"
M6GD_16XLARGE = "m6gd.16xlarge"
M6GD_METAL = "m6gd.metal"

M5_LARGE = "m5.large"
M5_XLARGE = "m5.xlarge"
M5_2XLARGE = "m5.2xlarge"
M5_4XLARGE = "m5.4xlarge"
M5_12XLARGE = "m5.12xlarge"
M5_24XLARGE = "m5.24xlarge"
M5_METAL = "m5.metal"

M5D_LARGE = "m5d.large"
M5D_XLARGE = "m5d.xlarge"
M5D_2XLARGE = "m5d.2xlarge"
M5D_4XLARGE = "m5d.4xlarge"
M5D_12XLARGE = "m5d.12xlarge"
M5D_24XLARGE = "m5d.24xlarge"
M5D_METAL = "m5d.metal"

M5A_LARGE = "m5a.large"
M5A_XLARGE = "m5a.xlarge"
M5A_2XLARGE = "m5a.2xlarge"
M5A_4XLARGE = "m5a.4xlarge"
M5A_12XLARGE = "m5a.12xlarge"
M5A_24XLARGE = "m5a.24xlarge"

M5AD_LARGE = "m5ad.large"
M5AD_XLARGE = "m5ad.xlarge"
M5AD_2XLARGE = "m5ad.2xlarge"
M5AD_4XLARGE = "m5ad.4xlarge"
M5AD_12XLARGE = "m5ad.12xlarge"
M5AD_24XLARGE = "m5ad.24xlarge"

M5N_LARGE = "m5n.large"
M5N_XLARGE = "m5n.xlarge"
M5N_2XLARGE = "m5n.2xlarge"
M5N_4XLARGE = "m5n.4xlarge"
M5N_8XLARGE = "m5n.8xlarge"
M5N_12XLARGE = "m5n.12xlarge"
M5N_16XLARGE = "m5n.16xlarge"
M5N_24XLARGE = "m5n.24xlarge"
M5DN_LARGE = "m5dn.large"
M5DN_XLARGE = "m5dn.xlarge"
M5DN_2XLARGE = "m5dn.2xlarge"
M5DN_4XLARGE = "m5dn.4xlarge"
M5DN_8XLARGE = "m5dn.8xlarge"
M5DN_12XLARGE = "m5dn.12xlarge"
M5DN_16XLARGE = "m5dn.16xlarge"
M5DN_24XLARGE = "m5dn.24xlarge"

M4_LARGE = "m4.large"
M4_XLARGE = "m4.xlarge"
M4_2XLARGE = "m4.2xlarge"
M4_4XLARGE = "m4.4xlarge"
M4_10XLARGE = "m4.10xlarge"
M4_16XLARGE = "m4.16xlarge"

M3_MEDIUM = "m3.medium"
M3_LARGE = "m3.large"
M3_XLARGE = "m3.xlarge"
M3_2XLARGE = "m3.2xlarge"

A1_MEDIUM = "a1.medium"
A1_LARGE = "a1.large"
A1_XLARGE = "a1.xlarge"
A1_2XLARGE = "a1.2xlarge"
A1_4XLARGE = "a1.4xlarge"
A1_METAL = "a1.metal"

C3_LARGE = "c3.large"
C3_XLARGE = "c3.xlarge"
C3_2XLARGE = "c3.2xlarge"
C3_4XLARGE = "c3.4xlarge"
C3_8XLARGE = "c3.8xlarge"

C4_LARGE = "c4.large"
C4_XLARGE = "c4.xlarge"
C4_2XLARGE = "c4.2xlarge"
C4_4XLARGE = "c4.4xlarge"
C4_8XLARGE = "c4.8xlarge"

C5_LARGE = "c5.large"
C5_XLARGE = "c5.xlarge"
C5_2XLARGE = "c5.2xlarge"
C5_4XLARGE = "c5.4xlarge"
C5_9XLARGE = "c5.9xlarge"
C5_18XLARGE = "c5.18xlarge"
C5_METAL = "c5.metal"

C5A_LARGE = "c5a.large"
C5A_XLARGE = "c5a.xlarge"
C5A_2XLARGE = "c5a.2xlarge"
C5A_4XLARGE = "c5a.4xlarge"
C5A_8XLARGE = "c5a.8xlarge"
C5A_12XLARGE = "c5a.12xlarge"
C5A_16XLARGE = "c5a.16xlarge"
C5A_24XLARGE = "c5a.24xlarge"

C5D_LARGE = "c5d.large"
C5D_XLARGE = "c5d.xlarge"
C5D_2XLARGE = "c5d.2xlarge"
C5D_4XLARGE = "c5d.4xlarge"
C5D_9XLARGE = "c5d.9xlarge"
C5D_18XLARGE = "c5d.18xlarge"
C5D_METAL = "c5d.metal"

C5N_LARGE = "c5n.large"
C5N_XLARGE = "c5n.xlarge"
C5N_2XLARGE = "c5n.2xlarge"
C5N_4XLARGE = "c5n.4xlarge"
C5N_9XLARGE = "c5n.9xlarge"
C5N_18XLARGE = "c5n.18xlarge"
C5N_METAL = "c5n.metal"

C6G_MEDIUM = "c6g.medium"
C6G_LARGE = "c6g.large"
C6G_XLARGE = "c6g.xlarge"
C6G_2XLARGE = "c6g.2xlarge"
C6G_4XLARGE = "c6g.4xlarge"
C6G_8XLARGE = "c6g.8xlarge"
C6G_12XLARGE = "c6g.12xlarge"
C6G_16XLARGE = "c6g.16xlarge"
C6G_METAL = "c6g.metal"

C6GD_MEDIUM = "c6gd.medium"
C6GD_LARGE = "c6gd.large"
C6GD_XLARGE = "c6gd.xlarge"
C6GD_2XLARGE = "c6gd.2xlarge"
C6GD_4XLARGE = "c6gd.4xlarge"
C6GD_8XLARGE = "c6gd.8xlarge"
C6GD_12XLARGE = "c6gd.12xlarge"
C6GD_16XLARGE = "c6gd.16xlarge"
C6GD_METAL = "c6gd.metal"

C6GN_MEDIUM = "c6gn.medium"
C6GN_LARGE = "c6gn.large"
C6GN_XLARGE = "c6gn.xlarge"
C6GN_2XLARGE = "c6gn.2xlarge"
C6GN_4XLARGE = "c6gn.4xlarge"
C6GN_8XLARGE = "c6gn.8xlarge"
C6GN_12XLARGE = "c6gn.12xlarge"
C6GN_16XLARGE = "c6gn.16xlarge"

R3_LARGE = "r3.large"
R3_XLARGE = "r3.xlarge"
R3_2XLARGE = "r3.2xlarge"
R3_4XLARGE = "r3.4xlarge"
R3_8XLARGE = "r3.8xlarge"

G2_2XLARGE = "g2.2xlarge"
G2_8XLARGE = "g2.8xlarge"

G3S_XLARGE = "g3s.xlarge"
G3_4XLARGE = "g3.4xlarge"
G3_8XLARGE = "g3.8xlarge"
G3_16XLARGE = "g3.16xlarge"

G4AD_4XLARGE = "g4ad.4xlarge"
G4AD_8XLARGE = "g4ad.8xlarge"
G4AD_16XLARGE = "g4ad.16xlarge"

G4DN_XLARGE = "g4dn.xlarge"
G4DN_2XLARGE = "g4dn.2xlarge"
G4DN_4XLARGE = "g4dn.4xlarge"
G4DN_8XLARGE = "g4dn.8xlarge"
G4DN_12XLARGE = "g4dn.12xlarge"
G4DN_16XLARGE = "g4dn.16xlarge"
G4DN_METAL = "g4dn.metal"

I2_XLARGE = "i2.xlarge"
I2_2XLARGE = "i2.2xlarge"
I2_4XLARGE = "i2.4xlarge"
I2_8XLARGE = "i2.8xlarge"

H1_2XLARGE = "h1.2xlarge"
H1_4XLARGE = "h1.4xlarge"
H1_8XLARGE = "h1.8xlarge"
H1_16XLARGE = "h1.16xlarge"

I3_LARGE = "i3.large"
I3_XLARGE = "i3.xlarge"
I3_2XLARGE = "i3.2xlarge"
I3_4XLARGE = "i3.4xlarge"
I3_8XLARGE = "i3.8xlarge"
I3_16XLARGE = "i3.16xlarge"
I3_METAL = "i3.metal"

I3EN_LARGE = "i3en.large"
I3EN_XLARGE = "i3en.xlarge"
I3EN_2XLARGE = "i3en.2xlarge"
I3EN_3XLARGE = "i3en.3xlarge"
I3EN_6XLARGE = "i3en.6xlarge"
I3EN_12XLARGE = "i3en.12xlarge"
I3EN_24XLARGE = "i3en.24xlarge"
I3EN_METAL = "i3en.metal"

D2_XLARGE = "d2.xlarge"
D2_2XLARGE = "d2.2xlarge"
D2_4XLARGE = "d2.4xlarge"
D2_8XLARGE = "d2.8xlarge"

D3_XLARGE = "d3.xlarge"
D3_2XLARGE = "d3.2xlarge"
D3_4XLARGE = "d3.4xlarge"
D3_8XLARGE = "d3.8xlarge"

D3EN_XLARGE = "d3en.xlarge"
D3EN_2XLARGE = "d3en.2xlarge"
D3EN_4XLARGE = "d3en.4xlarge"
D3EN_6XLARGE = "d3en.6xlarge"
D3EN_8XLARGE = "d3en.8xlarge"
D3EN_12XLARGE = "d3en.12xlarge"

HS1_8XLARGE = "hs1.8xlarge"

M1_SMALL = "m1.small"
M1_MEDIUM = "m1.medium"
M1_LARGE = "m1.large"
M1_XLARGE = "m1.xlarge"

C1_MEDIUM = "c1.medium"
C1_XLARGE = "c1.xlarge"
CC2_8XLARGE = "cc2.8xlarge"

CG1_4XLARGE = "cg1.4xlarge"

M2_XLARGE = "m2.xlarge"
M2_2XLARGE = "m2.2xlarge"
M2_4XLARGE = "m2.4xlarge"
CR1_8XLARGE = "cr1.8xlarge"

HI1_4XLARGE = "hi1.4xlarge"

T1_MICRO = "t1.micro"

X1_32XLARGE = "x1.32xlarge"
X1_16XLARGE = "x1.16xlarge"

X1E_XLARGE = "x1e.xlarge"
X1E_2XLARGE = "x1e.2xlarge"
X1E_4XLARGE = "x1e.4xlarge"
X1E_8XLARGE = "x1e.8xlarge"
X1E_16XLARGE = "x1e.16xlarge"
X1E_32XLARGE = "x1e.32xlarge"

U_6TB1_METAL = "u-6tb1.metal"
U_9TB1_METAL = "u-9tb1.metal"
U_12TB1_METAL = "u-12tb1.metal"
U_18TB1_METAL = "u-18tb1.metal"
U_24TB1_METAL = "u-24tb1.metal"

Z1D_LARGE = "z1d.large"
Z1D_XLARGE = "z1d.xlarge"
Z1D_2XLARGE = "z1d.2xlarge"
Z1D_3XLARGE = "z1d.3xlarge"
Z1D_6XLARGE = "z1d.6xlarge"
Z1D_12XLARGE = "z1d.12xlarge"
Z1D_METAL = "z1d.metal"

R4_LARGE = "r4.large"
R4_XLARGE = "r4.xlarge"
R4_2XLARGE = "r4.2xlarge"
R4_4XLARGE = "r4.4xlarge"
R4_8XLARGE = "r4.8xlarge"
R4_16XLARGE = "r4.16xlarge"

R5_LARGE = "r5.large"
R5_XLARGE = "r5.xlarge"
R5_2XLARGE = "r5.2xlarge"
R5_4XLARGE = "r5.4xlarge"
R5_12XLARGE = "r5.12xlarge"
R5_24XLARGE = "r5.24xlarge"
R5_METAL = "r5.metal"

R5D_LARGE = "r5d.large"
R5D_XLARGE = "r5d.xlarge"
R5D_2XLARGE = "r5d.2xlarge"
R5D_4XLARGE = "r5d.4xlarge"
R5D_12XLARGE = "r5d.12xlarge"
R5D_24XLARGE = "r5d.24xlarge"
R5D_METAL = "r5d.metal"

R5A_LARGE = "r5a.large"
R5A_XLARGE = "r5a.xlarge"
R5A_2XLARGE = "r5a.2xlarge"
R5A_4XLARGE = "r5a.4xlarge"
R5A_12XLARGE = "r5a.12xlarge"
R5A_24XLARGE = "r5a.24xlarge"

R5AD_LARGE = "r5ad.large"
R5AD_XLARGE = "r5ad.xlarge"
R5AD_2XLARGE = "r5ad.2xlarge"
R5AD_4XLARGE = "r5ad.4xlarge"
R5AD_12XLARGE = "r5ad.12xlarge"
R5AD_24XLARGE = "r5ad.24xlarge"

R5N_LARGE = "r5n.large"
R5N_XLARGE = "r5n.xlarge"
R5N_2XLARGE = "r5n.2xlarge"
R5N_4XLARGE = "r5n.4xlarge"
R5N_8XLARGE = "r5n.8xlarge"
R5N_12XLARGE = "r5n.12xlarge"
R5N_16XLARGE = "r5n.16xlarge"
R5N_24XLARGE = "r5n.24xlarge"
R5DN_LARGE = "r5dn.large"
R5DN_XLARGE = "r5dn.xlarge"
R5DN_2XLARGE = "r5dn.2xlarge"
R5DN_4XLARGE = "r5dn.4xlarge"
R5DN_8XLARGE = "r5dn.8xlarge"
R5DN_12XLARGE = "r5dn.12xlarge"
R5DN_16XLARGE = "r5dn.16xlarge"
R5DN_24XLARGE = "r5dn.24xlarge"

R6G_MEDIUM = "r6g.medium"
R6G_LARGE = "r6g.large"
R6G_XLARGE = "r6g.xlarge"
R6G_2XLARGE = "r6g.2xlarge"
R6G_4XLARGE = "r6g.4xlarge"
R6G_8XLARGE = "r6g.8xlarge"
R6G_12XLARGE = "r6g.12xlarge"
R6G_16XLARGE = "r6g.16xlarge"
R6G_METAL = "r6g.metal"

R6GD_MEDIUM = "r6gd.medium"
R6GD_LARGE = "r6gd.large"
R6GD_XLARGE = "r6gd.xlarge"
R6GD_2XLARGE = "r6gd.2xlarge"
R6GD_4XLARGE = "r6gd.4xlarge"
R6GD_8XLARGE = "r6gd.8xlarge"
R6GD_12XLARGE = "r6gd.12xlarge"
R6GD_16XLARGE = "r6gd.16xlarge"
R6GD_METAL = "r6gd.metal"

P2_XLARGE = "p2.xlarge"
P2_8XLARGE = "p2.8xlarge"
P2_16XLARGE = "p2.16xlarge"

P3_2XLARGE = "p3.2xlarge"
P3_8XLARGE = "p3.8xlarge"
P3_16XLARGE = "p3.16xlarge"
P3DN_24XLARGE = "p3dn.24xlarge"

F1_2XLARGE = "f1.2xlarge"
F1_4XLARGE = "f1.4xlarge"
F1_16XLARGE = "f1.16xlarge"

INF1_XLARGE = "inf1.xlarge"
INF1_2XLARGE = "inf1.2xlarge"
INF1_6XLARGE = "inf1.6xlarge"
INF1_24XLARGE = "inf1.24xlarge"

#
# RDS DB instance classes
#

DB_T1_MICRO = "db.t1.micro"

DB_T2_MICRO = "db.t2.micro"
DB_T2_SMALL = "db.t2.small"
DB_T2_MEDIUM = "db.t2.medium"
DB_T2_LARGE = "db.t2.large"
DB_T2_XLARGE = "db.t2.xlarge"
DB_T2_2XLARGE = "db.t2.2xlarge"

DB_T3_MICRO = "db.t3.micro"
DB_T3_SMALL = "db.t3.small"
DB_T3_MEDIUM = "db.t3.medium"
DB_T3_LARGE = "db.t3.large"
DB_T3_XLARGE = "db.t3.xlarge"
DB_T3_2XLARGE = "db.t3.2xlarge"

DB_M1_SMALL = "db.m1.small"
DB_M1_MEDIUM = "db.m1.medium"
DB_M1_LARGE = "db.m1.large"
DB_M1_XLARGE = "db.m1.xlarge"

DB_M2_XLARGE = "db.m2.xlarge"
DB_M2_2XLARGE = "db.m2.2xlarge"
DB_M2_4XLARGE = "db.m2.4xlarge"

DB_M3_MEDIUM = "db.m3.medium"
DB_M3_LARGE = "db.m3.large"
DB_M3_XLARGE = "db.m3.xlarge"
DB_M3_2XLARGE = "db.m3.2xlarge"

DB_M4_LARGE = "db.m4.large"
DB_M4_XLARGE = "db.m4.xlarge"
DB_M4_2XLARGE = "db.m4.2xlarge"
DB_M4_4XLARGE = "db.m4.4xlarge"
DB_M4_10XLARGE = "db.m4.10xlarge"
DB_M4_16XLARGE = "db.m4.16xlarge"

DB_M5_LARGE = "db.m5.large"
DB_M5_XLARGE = "db.m5.xlarge"
DB_M5_2XLARGE = "db.m5.2xlarge"
DB_M5_4XLARGE = "db.m5.4xlarge"
DB_M5_8XLARGE = "db.m5.8xlarge"
DB_M5_12XLARGE = "db.m5.12xlarge"
DB_M5_16XLARGE = "db.m5.16xlarge"
DB_M5_24XLARGE = "db.m5.24xlarge"

DB_M5D_LARGE = "db.m5d.large"
DB_M5D_XLARGE = "db.m5d.xlarge"
DB_M5D_2XLARGE = "db.m5d.2xlarge"
DB_M5D_4XLARGE = "db.m5d.4xlarge"
DB_M5D_8XLARGE = "db.m5d.8xlarge"
DB_M5D_12XLARGE = "db.m5d.12xlarge"
DB_M5D_16XLARGE = "db.m5d.16xlarge"
DB_M5D_24XLARGE = "db.m5d.24xlarge"

DB_M6G_LARGE = "db.m6g.large"
DB_M6G_XLARGE = "db.m6g.xlarge"
DB_M6G_2XLARGE = "db.m6g.2xlarge"
DB_M6G_4XLARGE = "db.m6g.4xlarge"
DB_M6G_8XLARGE = "db.m6g.8xlarge"
DB_M6G_12XLARGE = "db.m6g.12xlarge"
DB_M6G_16XLARGE = "db.m6g.16xlarge"

DB_R3_LARGE = "db.r3.large"
DB_R3_XLARGE = "db.r3.xlarge"
DB_R3_2XLARGE = "db.r3.2xlarge"
DB_R3_4XLARGE = "db.r3.4xlarge"
DB_R3_8XLARGE = "db.r3.8xlarge"

DB_R4_LARGE = "db.r4.large"
DB_R4_XLARGE = "db.r4.xlarge"
DB_R4_2XLARGE = "db.r4.2xlarge"
DB_R4_4XLARGE = "db.r4.4xlarge"
DB_R4_8XLARGE = "db.r4.8xlarge"
DB_R4_16XLARGE = "db.r4.16xlarge"

DB_R5_LARGE = "db.r5.large"
DB_R5_XLARGE = "db.r5.xlarge"
DB_R5_2XLARGE = "db.r5.2xlarge"
DB_R5_4XLARGE = "db.r5.4xlarge"
DB_R5_8XLARGE = "db.r5.8xlarge"
DB_R5_12XLARGE = "db.r5.12xlarge"
DB_R5_16XLARGE = "db.r5.16xlarge"
DB_R5_24XLARGE = "db.r5.24xlarge"

DB_R6G_LARGE = "db.r6g.large"
DB_R6G_XLARGE = "db.r6g.xlarge"
DB_R6G_2XLARGE = "db.r6g.2xlarge"
DB_R6G_4XLARGE = "db.r6g.4xlarge"
DB_R6G_8XLARGE = "db.r6g.8xlarge"
DB_R6G_12XLARGE = "db.r6g.12xlarge"
DB_R6G_16XLARGE = "db.r6g.16xlarge"

DB_X1_16XLARGE = "db.x1.16xlarge"
DB_X1_32XLARGE = "db.x1.32xlarge"

DB_X1E_XLARGE = "db.x1e.xlarge"
DB_X1E_2XLARGE = "db.x1e.2xlarge"
DB_X1E_4XLARGE = "db.x1e.4xlarge"
DB_X1E_8XLARGE = "db.x1e.8xlarge"
DB_X1E_16XLARGE = "db.x1e.16xlarge"
DB_X1E_32XLARGE = "db.x1e.32xlarge"

DB_CR1_8XLARGE = "db.cr1.8xlarge"

#
# ElastiCache node types
#

CACHE_T2_MICRO = "cache.t2.micro"
CACHE_T2_SMALL = "cache.t2.small"
CACHE_T2_MEDIUM = "cache.t2.medium"

CACHE_M3_MEDIUM = "cache.m3.medium"
CACHE_M3_LARGE = "cache.m3.large"
CACHE_M3_XLARGE = "cache.m3.xlarge"
CACHE_M3_2XLARGE = "cache.m3.2xlarge"

CACHE_R3_LARGE = "cache.r3.large"
CACHE_R3_XLARGE = "cache.r3.xlarge"
CACHE_R3_2XLARGE = "cache.r3.2xlarge"
CACHE_R3_4XLARGE = "cache.r3.4xlarge"
CACHE_R3_8XLARGE = "cache.r3.8xlarge"

CACHE_M1_SMALL = "cache.m1.small"
CACHE_M1_MEDIUM = "cache.m1.medium"
CACHE_M1_LARGE = "cache.m1.large"
CACHE_M1_XLARGE = "cache.m1.xlarge"

CACHE_M2_XLARGE = "cache.m2.xlarge"
CACHE_M2_2XLARGE = "cache.m2.2xlarge"
CACHE_M2_4XLARGE = "cache.m2.4xlarge"

CACHE_C1_XLARGE = "cache.c1.xlarge"

CACHE_T1_MICRO = "cache.t1.micro"

#
# Elasticsearch instance types
#

# Note: t2.micro.elasticsearch is deprecated.
ELASTICSEARCH_T2_MICRO = "t2.micro.elasticsearch"
ELASTICSEARCH_T2_SMALL = "t2.small.elasticsearch"
ELASTICSEARCH_T2_MEDIUM = "t2.medium.elasticsearch"

ELASTICSEARCH_T3_SMALL = "t3.small.elasticsearch"
ELASTICSEARCH_T3_MEDIUM = "t3.medium.elasticsearch"

ELASTICSEARCH_M3_MEDIUM = "m3.medium.elasticsearch"
ELASTICSEARCH_M3_LARGE = "m3.large.elasticsearch"
ELASTICSEARCH_M3_XLARGE = "m3.xlarge.elasticsearch"
ELASTICSEARCH_M3_2XLARGE = "m3.2xlarge.elasticsearch"

ELASTICSEARCH_M4_LARGE = "m4.large.elasticsearch"
ELASTICSEARCH_M4_XLARGE = "m4.xlarge.elasticsearch"
ELASTICSEARCH_M4_2XLARGE = "m4.2xlarge.elasticsearch"
ELASTICSEARCH_M4_4XLARGE = "m4.4xlarge.elasticsearch"
ELASTICSEARCH_M4_10XLARGE = "m4.10xlarge.elasticsearch"

ELASTICSEARCH_M5_LARGE = "m5.large.elasticsearch"
ELASTICSEARCH_M5_XLARGE = "m5.xlarge.elasticsearch"
ELASTICSEARCH_M5_2XLARGE = "m5.2xlarge.elasticsearch"
ELASTICSEARCH_M5_4XLARGE = "m5.4xlarge.elasticsearch"
ELASTICSEARCH_M5_12XLARGE = "m5.12xlarge.elasticsearch"

ELASTICSEARCH_M6G_LARGE = "m6g.large.elasticsearch"
ELASTICSEARCH_M6G_XLARGE = "m6g.xlarge.elasticsearch"
ELASTICSEARCH_M6G_2XLARGE = "m6g.2xlarge.elasticsearch"
ELASTICSEARCH_M6G_4XLARGE = "m6g.4xlarge.elasticsearch"
ELASTICSEARCH_M6G_8XLARGE = "m6g.8xlarge.elasticsearch"
ELASTICSEARCH_M6G_12XLARGE = "m6g.12xlarge.elasticsearch"

ELASTICSEARCH_C4_LARGE = "c4.large.elasticsearch"
ELASTICSEARCH_C4_XLARGE = "c4.xlarge.elasticsearch"
ELASTICSEARCH_C4_2XLARGE = "c4.2xlarge.elasticsearch"
ELASTICSEARCH_C4_4XLARGE = "c4.4xlarge.elasticsearch"
ELASTICSEARCH_C4_8XLARGE = "c4.8xlarge.elasticsearch"

ELASTICSEARCH_C5_LARGE = "c5.large.elasticsearch"
ELASTICSEARCH_C5_XLARGE = "c5.xlarge.elasticsearch"
ELASTICSEARCH_C5_2XLARGE = "c5.2xlarge.elasticsearch"
ELASTICSEARCH_C5_4XLARGE = "c5.4xlarge.elasticsearch"
ELASTICSEARCH_C5_9XLARGE = "c5.9xlarge.elasticsearch"
ELASTICSEARCH_C5_18XLARGE = "c5.18xlarge.elasticsearch"

ELASTICSEARCH_C6G_LARGE = "c6g.large.elasticsearch"
ELASTICSEARCH_C6G_XLARGE = "c6g.xlarge.elasticsearch"
ELASTICSEARCH_C6G_2XLARGE = "c6g.2xlarge.elasticsearch"
ELASTICSEARCH_C6G_4XLARGE = "c6g.4xlarge.elasticsearch"
ELASTICSEARCH_C6G_8XLARGE = "c6g.8xlarge.elasticsearch"
ELASTICSEARCH_C6G_12XLARGE = "c6g.12xlarge.elasticsearch"

ELASTICSEARCH_R3_LARGE = "r3.large.elasticsearch"
ELASTICSEARCH_R3_XLARGE = "r3.xlarge.elasticsearch"
ELASTICSEARCH_R3_2XLARGE = "r3.2xlarge.elasticsearch"
ELASTICSEARCH_R3_4XLARGE = "r3.4xlarge.elasticsearch"
ELASTICSEARCH_R3_8XLARGE = "r3.8xlarge.elasticsearch"

ELASTICSEARCH_R4_LARGE = "r4.large.elasticsearch"
ELASTICSEARCH_R4_XLARGE = "r4.xlarge.elasticsearch"
ELASTICSEARCH_R4_2XLARGE = "r4.2xlarge.elasticsearch"
ELASTICSEARCH_R4_4XLARGE = "r4.4xlarge.elasticsearch"
ELASTICSEARCH_R4_8XLARGE = "r4.8xlarge.elasticsearch"
ELASTICSEARCH_R4_16XLARGE = "r4.16xlarge.elasticsearch"

ELASTICSEARCH_R5_LARGE = "r5.large.elasticsearch"
ELASTICSEARCH_R5_XLARGE = "r5.xlarge.elasticsearch"
ELASTICSEARCH_R5_2XLARGE = "r5.2xlarge.elasticsearch"
ELASTICSEARCH_R5_4XLARGE = "r5.4xlarge.elasticsearch"
ELASTICSEARCH_R5_12XLARGE = "r5.12xlarge.elasticsearch"

ELASTICSEARCH_R6G_LARGE = "r6g.large.elasticsearch"
ELASTICSEARCH_R6G_XLARGE = "r6g.xlarge.elasticsearch"
ELASTICSEARCH_R6G_2XLARGE = "r6g.2xlarge.elasticsearch"
ELASTICSEARCH_R6G_4XLARGE = "r6g.4xlarge.elasticsearch"
ELASTICSEARCH_R6G_8XLARGE = "r6g.8xlarge.elasticsearch"
ELASTICSEARCH_R6G_12XLARGE = "r6g.12xlarge.elasticsearch"

ELASTICSEARCH_R6GD_LARGE = "r6gd.large.elasticsearch"
ELASTICSEARCH_R6GD_XLARGE = "r6gd.xlarge.elasticsearch"
ELASTICSEARCH_R6GD_2XLARGE = "r6gd.2xlarge.elasticsearch"
ELASTICSEARCH_R6GD_4XLARGE = "r6gd.4xlarge.elasticsearch"
ELASTICSEARCH_R6GD_8XLARGE = "r6gd.8xlarge.elasticsearch"
ELASTICSEARCH_R6GD_12XLARGE = "r6gd.12xlarge.elasticsearch"
ELASTICSEARCH_R6GD_16XLARGE = "r6gd.16xlarge.elasticsearch"

ELASTICSEARCH_I2_XLARGE = "i2.xlarge.elasticsearch"
ELASTICSEARCH_I2_2XLARGE = "i2.2xlarge.elasticsearch"

ELASTICSEARCH_I3_LARGE = "i3.large.elasticsearch"
ELASTICSEARCH_I3_XLARGE = "i3.xlarge.elasticsearch"
ELASTICSEARCH_I3_2XLARGE = "i3.2xlarge.elasticsearch"
ELASTICSEARCH_I3_4XLARGE = "i3.4xlarge.elasticsearch"
ELASTICSEARCH_I3_8XLARGE = "i3.8xlarge.elasticsearch"
ELASTICSEARCH_I3_16XLARGE = "i3.16xlarge.elasticsearch"

ELASTICSEARCH_ULTRAWARM1_MEDIUM = "ultrawarm1.medium.elasticsearch"
ELASTICSEARCH_ULTRAWARM1_LARGE = "ultrawarm1.large.elasticsearch"

#
# Kafka brokers instance types
#

KAFKA_M5_LARGE = "kafka.m5.large"
KAFKA_M5_XLARGE = "kafka.m5.xlarge"
KAFKA_M5_2XLARGE = "kafka.m5.2xlarge"
KAFKA_M5_4XLARGE = "kafka.m5.4xlarge"
KAFKA_M5_12XLARGE = "kafka.m5.12xlarge"
KAFKA_M5_24XLARGE = "kafka.m5.24xlarge"

#
# Parameter types
#

STRING = "String"
NUMBER = "Number"
LIST_OF_NUMBERS = "List<Number>"
COMMA_DELIMITED_LIST = "CommaDelimitedList"

AVAILABILITY_ZONE_NAME = "AWS::EC2::AvailabilityZone::Name"
IMAGE_ID = "AWS::EC2::Image::Id"
INSTANCE_ID = "AWS::EC2::Instance::Id"
KEY_PAIR_NAME = "AWS::EC2::KeyPair::KeyName"
SECURITY_GROUP_NAME = "AWS::EC2::SecurityGroup::GroupName"
SECURITY_GROUP_ID = "AWS::EC2::SecurityGroup::Id"
SUBNET_ID = "AWS::EC2::Subnet::Id"
VOLUME_ID = "AWS::EC2::Volume::Id"
VPC_ID = "AWS::EC2::VPC::Id"
HOSTED_ZONE_ID = "AWS::Route53::HostedZone::Id"

LIST_OF_AVAILABILITY_ZONE_NAMES = "List<AWS::EC2::AvailabilityZone::Name>"
LIST_OF_IMAGE_ID = "List<AWS::EC2::Image::Id>"
LIST_OF_INSTANCE_IDS = "List<AWS::EC2::Instance::Id>"
LIST_OF_SECURITY_GROUP_NAMES = "List<AWS::EC2::SecurityGroup::GroupName>"
LIST_OF_SECURITY_GROUP_IDS = "List<AWS::EC2::SecurityGroup::Id>"
LIST_OF_SUBNET_IDS = "List<AWS::EC2::Subnet::Id>"
LIST_OF_VOLUME_IDS = "List<AWS::EC2::Volume::Id>"
LIST_OF_VPC_IDS = "List<AWS::EC2::VPC::Id>"
LIST_OF_HOSTED_ZONE_IDS = "List<AWS::Route53::HostedZone::Id>"

#
# Logs
#
LOGS_ALLOWED_RETENTION_DAYS = [
    1,
    3,
    5,
    7,
    14,
    30,
    60,
    90,
    120,
    150,
    180,
    365,
    400,
    545,
    731,
    1827,
    3653,
]

#
# Route53
#

CLOUDFRONT_HOSTEDZONEID = "Z2FDTNDATAQYW2"



# Copyright (c) 2012-2019, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 5.3.0


from . import AWSObject, AWSProperty
from .validators import boolean


class S3(AWSProperty):
    props = {
        "Bucket": (str, True),
        "Key": (str, True),
        "ObjectVersion": (str, False),
    }


class Code(AWSProperty):
    props = {
        "S3": (S3, True),
    }


class GitHubRepository(AWSObject):
    resource_type = "AWS::CodeStar::GitHubRepository"

    props = {
        "Code": (Code, False),
        "EnableIssues": (boolean, False),
        "IsPrivate": (boolean, False),
        "RepositoryAccessToken": (str, True),
        "RepositoryDescription": (str, False),
        "RepositoryName": (str, True),
        "RepositoryOwner": (str, True),
    }



# Copyright (c) 2012-2019, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


from . import AWSObject, AWSProperty, Tags
from .validators import boolean, containerlevelmetrics_status, integer


class CorsRule(AWSProperty):
    props = {
        "AllowedHeaders": ([str], False),
        "AllowedMethods": ([str], False),
        "AllowedOrigins": ([str], False),
        "ExposeHeaders": ([str], False),
        "MaxAgeSeconds": (integer, False),
    }


class MetricPolicyRule(AWSProperty):
    props = {
        "ObjectGroup": (str, True),
        "ObjectGroupName": (str, True),
    }


class MetricPolicy(AWSProperty):
    props = {
        "ContainerLevelMetrics": (containerlevelmetrics_status, True),
        "MetricPolicyRules": ([MetricPolicyRule], False),
    }


class Container(AWSObject):
    resource_type = "AWS::MediaStore::Container"

    props = {
        "AccessLoggingEnabled": (boolean, False),
        "ContainerName": (str, True),
        "CorsPolicy": ([CorsRule], False),
        "LifecyclePolicy": (str, False),
        "MetricPolicy": (MetricPolicy, False),
        "Policy": (str, False),
        "Tags": (Tags, False),
    }



# Converted from IAM_Users_Groups_and_Policies.template located at:
# http://aws.amazon.com/cloudformation/aws-cloudformation-templates/

from troposphere import GetAtt, Output, Ref, Template
from troposphere.iam import (
    AccessKey,
    Group,
    LoginProfile,
    PolicyType,
    User,
    UserToGroupAddition,
)

t = Template()

t.set_description(
    "AWS CloudFormation Sample Template: This template "
    "demonstrates the creation of IAM User/Group."
)

cfnuser = t.add_resource(
    User("CFNUser", LoginProfile=LoginProfile(Password="Password"))
)

cfnusergroup = t.add_resource(Group("CFNUserGroup"))
cfnadmingroup = t.add_resource(Group("CFNAdminGroup"))

cfnkeys = t.add_resource(AccessKey("CFNKeys", Status="Active", UserName=Ref(cfnuser)))

users = t.add_resource(
    UserToGroupAddition(
        "Users",
        GroupName=Ref(cfnusergroup),
        Users=[Ref(cfnuser)],
    )
)

admins = t.add_resource(
    UserToGroupAddition(
        "Admins",
        GroupName=Ref(cfnadmingroup),
        Users=[Ref(cfnuser)],
    )
)

t.add_resource(
    PolicyType(
        "CFNUserPolicies",
        PolicyName="CFNUsers",
        Groups=[Ref(cfnadmingroup)],
        PolicyDocument={
            "Version": "2012-10-17",
            "Statement": [
                {
                    "Effect": "Allow",
                    "Action": [
                        "cloudformation:Describe*",
                        "cloudformation:List*",
                        "cloudformation:Get*",
                    ],
                    "Resource": "*",
                }
            ],
        },
    )
)

t.add_output(
    Output(
        "AccessKey",
        Value=Ref(cfnkeys),
        Description="AWSAccessKeyId of new user",
    )
)

t.add_output(
    Output(
        "SecretKey",
        Value=GetAtt(cfnkeys, "SecretAccessKey"),
        Description="AWSSecretKey of new user",
    )
)

print(t.to_json())
